@@ -598,7 +598,7 @@ def is_unedited_config_file(content, template_content=None):
     # The jquery_url setting, present in 0.3.2 and later only, is
     # effectively auto-generated by the build system, so we need to
     # ignore it in the md5sum calculation for 0.3.2.
-    content = re.sub(b'\njquery_url\s*=\s*[^\n]+', b'', content)
+    content = re.sub(br'\njquery_url\s*=\s*[^\n]+', b'', content)
 
     # First determine if the config file has any effective content
     buffer = io.BytesIO(content)
