@@ -177,7 +177,7 @@ def test_configitem_options(tmpdir):
     f = tmpdir.join('astropy.cfg')
     with io.open(f.strpath, 'wb') as fd:
         apycfg.write(fd)
-    with io.open(f.strpath, 'rU', encoding='utf-8') as fd:
+    with io.open(f.strpath, 'r', encoding='utf-8') as fd:
         lns = [x.strip() for x in f.readlines()]
 
     assert 'tstnmo = op2' in lns
