@@ -167,14 +167,9 @@ def convolve(array, kernel, boundary='fill', fill_value=0.,
         array_dtype = array_internal.dtype
     elif isinstance(array, np.ndarray):
         # Note this won't copy if it doesn't have to -- which is okay
-        # because none of what follows modifies array_internal.  However,
-        # only numpy > 1.7 has support for no-copy astype, so we use
-        # a try/except because astropy supports 1.5 and 1.6
+        # because none of what follows modifies array_internal.
         array_dtype = array.dtype
-        try:
-            array_internal = array.astype(float, copy=False)
-        except TypeError:
-            array_internal = array.astype(float)
+        array_internal = array.astype(float, copy=False)
     else:
         raise TypeError("array should be a list or a Numpy array")
 
@@ -346,8 +341,8 @@ def convolve_fft(array, kernel, boundary='fill', fill_value=0.,
     * (optionally) It pads to the nearest 2^n size to improve FFT speed.
     * Its only valid ``mode`` is 'same' (i.e., the same shape array is returned)
     * It lets you use your own fft, e.g.,
-      `pyFFTW <http://pypi.python.org/pypi/pyFFTW>`_ or
-      `pyFFTW3 <http://pypi.python.org/pypi/PyFFTW3/0.2.1>`_ , which can lead to
+      `pyFFTW <https://pypi.python.org/pypi/pyFFTW>`_ or
+      `pyFFTW3 <https://pypi.python.org/pypi/PyFFTW3/0.2.1>`_ , which can lead to
       performance improvements, depending on your system configuration.  pyFFTW3
       is threaded, and therefore may yield significant performance benefits on
       multi-core machines at the cost of greater memory requirements.  Specify
@@ -739,7 +734,7 @@ def convolve_fft(array, kernel, boundary='fill', fill_value=0.,
         rifft = (ifftn(fftmult))
 
     if preserve_nan:
-        rifft[nanmaskarray] = np.nan
+        rifft[arrayslices][nanmaskarray] = np.nan
 
     if crop:
         result = rifft[arrayslices].real
