@@ -4,11 +4,13 @@ from __future__ import (absolute_import, division, print_function,
 
 import itertools
 
+import pytest
 import numpy as np
 from numpy.testing import assert_array_almost_equal_nulp, assert_allclose
 
 from ..convolve import convolve_fft
-from ...tests.helper import pytest
+from ...tests.helper import catch_warnings
+from ...utils.exceptions import AstropyUserWarning
 
 
 VALID_DTYPES = []
@@ -17,6 +19,7 @@ for dtype_array in ['>f4', '<f4', '>f8', '<f8']:
         VALID_DTYPES.append((dtype_array, dtype_kernel))
 
 BOUNDARY_OPTIONS = [None, 'fill', 'wrap']
+NANTREATMENT_OPTIONS = ('interpolate', 'fill')
 
 """
 What does convolution mean?  We use the 'same size' assumption here (i.e.,
@@ -30,17 +33,22 @@ Convolved with [0, 1] = [0, 1, 2, 3, 4]
 """
 
 # NOTE: use_numpy_fft is redundant if you don't have FFTW installed
-option_names = ('boundary', 'interpolate_nan', 'normalize_kernel',
-                'ignore_edge_zeros')
-options = list(itertools.product(BOUNDARY_OPTIONS, (True, False),
-                                 (True, False), (True, False)))
-
+option_names = ('boundary', 'nan_treatment', 'normalize_kernel')
+options = list(itertools.product(BOUNDARY_OPTIONS,
+                                 NANTREATMENT_OPTIONS,
+                                 (True, False),
+                                 ))
+option_names_preserve_nan = ('boundary', 'nan_treatment',
+                             'normalize_kernel', 'preserve_nan')
+options_preserve_nan = list(itertools.product(BOUNDARY_OPTIONS,
+                                              NANTREATMENT_OPTIONS,
+                                              (True, False),
+                                              (True, False)))
 
 class TestConvolve1D(object):
 
     @pytest.mark.parametrize(option_names, options)
-    def test_unity_1_none(self, boundary, interpolate_nan, normalize_kernel,
-                          ignore_edge_zeros):
+    def test_unity_1_none(self, boundary, nan_treatment, normalize_kernel):
         '''
         Test that a unit kernel with a single element returns the same array
         '''
@@ -50,15 +58,13 @@ class TestConvolve1D(object):
         y = np.array([1.], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
-                         normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         nan_treatment=nan_treatment,
+                         normalize_kernel=normalize_kernel)
 
         assert_array_almost_equal_nulp(z, x, 10)
 
     @pytest.mark.parametrize(option_names, options)
-    def test_unity_3(self, boundary, interpolate_nan, normalize_kernel,
-                     ignore_edge_zeros):
+    def test_unity_3(self, boundary, nan_treatment, normalize_kernel):
         '''
         Test that a unit kernel with three elements returns the same array
         (except when boundary is None).
@@ -69,15 +75,13 @@ class TestConvolve1D(object):
         y = np.array([0., 1., 0.], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
-                         normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         nan_treatment=nan_treatment,
+                         normalize_kernel=normalize_kernel)
 
         assert_array_almost_equal_nulp(z, x, 10)
 
     @pytest.mark.parametrize(option_names, options)
-    def test_uniform_3(self, boundary, interpolate_nan, normalize_kernel,
-                       ignore_edge_zeros):
+    def test_uniform_3(self, boundary, nan_treatment, normalize_kernel):
         '''
         Test that the different modes are producing the correct results using
         a uniform kernel with three elements
@@ -88,17 +92,55 @@ class TestConvolve1D(object):
         y = np.array([1., 1., 1.], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
-                         normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         nan_treatment=nan_treatment,
+                         normalize_kernel=normalize_kernel)
+
+        answer_key = (boundary, nan_treatment, normalize_kernel)
 
         answer_dict = {
-            'sum': np.array([1., 4., 3.], dtype='float64'),
-            'sum_zeros': np.array([1., 4., 3.], dtype='float64'),
-            'sum_nozeros': np.array([1., 4., 3.], dtype='float64'),
-            'average': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
+            'sum_fill_zeros': np.array([1., 4., 3.], dtype='float64'),
+            'average_fill_zeros': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
             'sum_wrap': np.array([4., 4., 4.], dtype='float64'),
             'average_wrap': np.array([4 / 3., 4 / 3., 4 / 3.], dtype='float64'),
+        }
+
+        result_dict = {
+            # boundary, nan_treatment, normalize_kernel
+            ('fill', 'interpolate', True): answer_dict['average_fill_zeros'],
+            ('wrap', 'interpolate', True): answer_dict['average_wrap'],
+            ('fill', 'interpolate', False): answer_dict['sum_fill_zeros'],
+            ('wrap', 'interpolate', False): answer_dict['sum_wrap'],
+        }
+        for k in list(result_dict.keys()):
+            result_dict[(k[0], 'fill', k[2])] = result_dict[k]
+        for k in list(result_dict.keys()):
+            if k[0] == 'fill':
+                result_dict[(None, k[1], k[2])] = result_dict[k]
+
+        assert_array_almost_equal_nulp(z, result_dict[answer_key], 10)
+
+    @pytest.mark.parametrize(option_names, options)
+    def test_halfity_3(self, boundary, nan_treatment, normalize_kernel):
+        '''
+        Test that the different modes are producing the correct results using
+        a uniform, non-unity kernel with three elements
+        '''
+
+        x = np.array([1., 0., 3.], dtype='float64')
+
+        y = np.array([0.5, 0.5, 0.5], dtype='float64')
+
+        z = convolve_fft(x, y, boundary=boundary,
+                         nan_treatment=nan_treatment,
+                         normalize_kernel=normalize_kernel)
+
+        answer_dict = {
+            'sum': np.array([0.5, 2.0, 1.5], dtype='float64'),
+            'sum_zeros': np.array([0.5, 2., 1.5], dtype='float64'),
+            'sum_nozeros': np.array([0.5, 2., 1.5], dtype='float64'),
+            'average': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
+            'sum_wrap': np.array([2., 2., 2.], dtype='float64'),
+            'average_wrap': np.array([4 / 3., 4 / 3., 4 / 3.], dtype='float64'),
             'average_zeros': np.array([1 / 3., 4 / 3., 1.], dtype='float64'),
             'average_nozeros': np.array([0.5, 4 / 3., 1.5], dtype='float64'),
         }
@@ -110,17 +152,15 @@ class TestConvolve1D(object):
 
         if boundary == 'wrap':
             answer_key += '_wrap'
-        elif ignore_edge_zeros:
-            answer_key += '_nozeros'
         else:
             # average = average_zeros; sum = sum_zeros
             answer_key += '_zeros'
 
         assert_array_almost_equal_nulp(z, answer_dict[answer_key], 10)
 
-    @pytest.mark.parametrize(option_names, options)
-    def test_unity_3_withnan(self, boundary, interpolate_nan, normalize_kernel,
-                             ignore_edge_zeros):
+    @pytest.mark.parametrize(option_names_preserve_nan, options_preserve_nan)
+    def test_unity_3_withnan(self, boundary, nan_treatment, normalize_kernel,
+                             preserve_nan):
         '''
         Test that a unit kernel with three elements returns the same array
         (except when boundary is None). This version includes a NaN value in
@@ -132,9 +172,14 @@ class TestConvolve1D(object):
         y = np.array([0., 1., 0.], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
+                         nan_treatment=nan_treatment,
                          normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         preserve_nan=preserve_nan)
+
+        if preserve_nan:
+            assert np.isnan(z[1])
+
+        z = np.nan_to_num(z)
 
         # for whatever reason, numpy's fft has very limited precision, and
         # the comparison fails unless you cast the float64 to a float16
@@ -143,22 +188,22 @@ class TestConvolve1D(object):
                 np.asarray(z, dtype=np.float16),
                 np.array([1., 0., 3.], dtype=np.float16), 10)
         # ASSERT equality to better than 16 bit but worse than 32 bit precision
-        assert np.all(np.abs(z - np.array([1., 0., 3.])) < 1e-14)
+        assert_allclose(z, np.array([1., 0., 3.]), atol=1e-14)
 
     inputs = (np.array([1., np.nan, 3.], dtype='float64'),
               np.array([1., np.inf, 3.], dtype='float64'))
     outputs = (np.array([1., 0., 3.], dtype='float64'),
                np.array([1., 0., 3.], dtype='float64'))
     options_unity1withnan = list(itertools.product(BOUNDARY_OPTIONS,
-                                                   (True, False),
+                                                   NANTREATMENT_OPTIONS,
                                                    (True, False),
                                                    (True, False),
                                                    inputs, outputs))
 
-    @pytest.mark.parametrize(option_names + ('inval', 'outval'),
+    @pytest.mark.parametrize(option_names_preserve_nan + ('inval', 'outval'),
                              options_unity1withnan)
-    def test_unity_1_withnan(self, boundary, interpolate_nan, normalize_kernel,
-                             ignore_edge_zeros, inval, outval):
+    def test_unity_1_withnan(self, boundary, nan_treatment, normalize_kernel,
+                             preserve_nan, inval, outval):
         '''
         Test that a unit kernel with three elements returns the same array
         (except when boundary is None). This version includes a NaN value in
@@ -170,20 +215,25 @@ class TestConvolve1D(object):
         y = np.array([1.], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
+                         nan_treatment=nan_treatment,
                          normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         preserve_nan=preserve_nan)
+
+        if preserve_nan:
+            assert np.isnan(z[1])
+
+        z = np.nan_to_num(z)
 
         # for whatever reason, numpy's fft has very limited precision, and
         # the comparison fails unless you cast the float64 to a float16
         if hasattr(np, 'float16'):
             assert_array_almost_equal_nulp(np.asarray(z, dtype=np.float16),
                                            np.array([1., 0., 3.], dtype=np.float16), 10)
-        assert np.all(np.abs(z - outval) < 1e-14)
+        assert_allclose(z, outval, atol=1e-14)
 
-    @pytest.mark.parametrize(option_names, options)
-    def test_uniform_3_withnan(self, boundary, interpolate_nan,
-                               normalize_kernel, ignore_edge_zeros):
+    @pytest.mark.parametrize(option_names_preserve_nan, options_preserve_nan)
+    def test_uniform_3_withnan(self, boundary, nan_treatment,
+                               normalize_kernel, preserve_nan):
         '''
         Test that the different modes are producing the correct results using
         a uniform kernel with three elements. This version includes a NaN
@@ -194,28 +244,42 @@ class TestConvolve1D(object):
 
         y = np.array([1., 1., 1.], dtype='float64')
 
+        # if nan_treatment and not normalize_kernel:
+        #     with pytest.raises(ValueError):
+        #         z = convolve_fft(x, y, boundary=boundary,
+        #                          nan_treatment=nan_treatment,
+        #                          normalize_kernel=normalize_kernel,
+        #                          ignore_edge_zeros=ignore_edge_zeros)
+        #     return
+
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
+                         nan_treatment=nan_treatment,
                          normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         preserve_nan=preserve_nan)
+
+        if preserve_nan:
+            assert np.isnan(z[1])
 
         answer_dict = {
             'sum': np.array([1., 4., 3.], dtype='float64'),
             'sum_nozeros': np.array([1., 4., 3.], dtype='float64'),
             'sum_zeros': np.array([1., 4., 3.], dtype='float64'),
-            'sum_zeros_noignan': np.array([1., 4., 3.], dtype='float64'),
-            'sum_nozeros_noignan': np.array([1., 4., 3.], dtype='float64'),
+            'sum_nozeros_interpnan': np.array([1., 4., 3.], dtype='float64'),
             'average': np.array([1., 2., 3.], dtype='float64'),
             'sum_wrap': np.array([4., 4., 4.], dtype='float64'),
-            'sum_wrap_noignan': np.array([4., 4., 4.], dtype='float64'),
-            'average_wrap': np.array([(1 + 3) / 2., 2., 2.], dtype='float64'),
-            'average_wrap_noignan': np.array([4 / 3., 4 / 3., 4 / 3.], dtype='float64'),
-            'average_nozeros': np.array([1, 2, 3], dtype='float64'),
-            'average_nozeros_noignan': np.array([1 / 2., 4 / 3., 3 / 2.], dtype='float64'),
-            'average_zeros': np.array([1 / 2., 4 / 2., 3 / 2.], dtype='float64'),
-            'average_zeros_noignan': np.array([1 / 3., 4 / 3., 3 / 3.], dtype='float64'),
+            'average_wrap': np.array([4/3., 4/3., 4/3.], dtype='float64'),
+            'average_wrap_interpnan': np.array([2, 2, 2], dtype='float64'),
+            'average_nozeros': np.array([1/2., 4/3., 3/2.], dtype='float64'),
+            # 'average_nozeros_interpnan': np.array([1 / 2., 4 / 3., 3 / 2.], dtype='float64'),
+            'average_nozeros_interpnan': np.array([1., 2., 3.], dtype='float64'),
+            'average_zeros': np.array([1 / 3., 4 / 3., 3 / 3.], dtype='float64'),
+            'average_zeros_interpnan': np.array([1 / 2., 4 / 2., 3 / 2.], dtype='float64'),
         }
 
+        for key in list(answer_dict.keys()):
+            if 'sum' in key:
+                answer_dict[key+"_interpnan"] = answer_dict[key] * 3./2.
+
         if normalize_kernel:
             answer_key = 'average'
         else:
@@ -223,34 +287,45 @@ class TestConvolve1D(object):
 
         if boundary == 'wrap':
             answer_key += '_wrap'
-        elif ignore_edge_zeros:
-            answer_key += '_nozeros'
         else:
             # average = average_zeros; sum = sum_zeros
             answer_key += '_zeros'
 
-        if not interpolate_nan:
-            answer_key += '_noignan'
+        if nan_treatment == 'interpolate':
+            answer_key += '_interpnan'
 
-        assert_array_almost_equal_nulp(z, answer_dict[answer_key], 10)
+        posns = np.where(np.isfinite(z))
+
+        assert_array_almost_equal_nulp(z[posns],
+                                       answer_dict[answer_key][posns], 10)
+
+    def test_nan_fill(self):
+
+        # Test masked array
+        array = np.array([1., np.nan, 3.], dtype='float64')
+        kernel = np.array([1, 1, 1])
+        masked_array = np.ma.masked_array(array, mask=[0, 1, 0])
+        result = convolve_fft(masked_array, kernel, boundary='fill', fill_value=np.nan)
+        assert_allclose(result, [1, 2, 3], atol=1e-14)
 
     def test_masked_array(self):
         """
         Check whether convolve_fft works with masked arrays.
         """
+
         # Test masked array
         array = np.array([1., np.nan, 3.], dtype='float64')
         kernel = np.array([1, 1, 1])
         masked_array = np.ma.masked_array(array, mask=[0, 1, 0])
-        result = convolve_fft(masked_array, kernel)
-        assert_allclose(result, [1, 4, 3], atol=1E-10)
+        result = convolve_fft(masked_array, kernel, boundary='fill', fill_value=np.nan)
+        assert_allclose(result, [1, 2, 3], atol=1e-14)
 
         # Test masked kernel
         array = np.array([1., np.nan, 3.], dtype='float64')
         kernel = np.array([1, 1, 1])
         masked_array = np.ma.masked_array(array, mask=[0, 1, 0])
-        result = convolve_fft(kernel, masked_array)
-        assert_allclose(result, [1, 4, 3], atol=1E-10)
+        result = convolve_fft(masked_array, kernel, boundary='fill', fill_value=np.nan)
+        assert_allclose(result, [1, 2, 3], atol=1e-14)
 
     def test_normalize_function(self):
         """
@@ -259,14 +334,44 @@ class TestConvolve1D(object):
         array = [1, 2, 3]
         kernel = [3, 3, 3]
         result = convolve_fft(array, kernel, normalize_kernel=np.max)
-        assert_allclose(result, [3, 6, 5], atol=1E-10)
+        assert_allclose(result, [3, 6, 5], atol=1e-14)
+
+    @pytest.mark.parametrize(option_names, options)
+    def test_normalization_is_respected(self, boundary,
+                                        nan_treatment,
+                                        normalize_kernel):
+        """
+        Check that if normalize_kernel is False then the normalization
+        tolerance is respected.
+        """
+        array = np.array([1, 2, 3])
+        # A simple identity kernel to which a non-zero normalization is added.
+        base_kernel = np.array([1.0])
+
+        # Use the same normalization error tolerance in all cases.
+        normalization_rtol = 1e-4
+
+        # Add the error below to the kernel.
+        norm_error = [normalization_rtol / 10, normalization_rtol * 10]
+
+        for err in norm_error:
+            kernel = base_kernel + err
+            result = convolve_fft(array, kernel,
+                                  normalize_kernel=normalize_kernel,
+                                  nan_treatment=nan_treatment,
+                                  normalization_zero_tol=normalization_rtol)
+            if normalize_kernel:
+                # Kernel has been normalized to 1.
+                assert_allclose(result, array, atol=1e-14)
+            else:
+                # Kernel should not have been normalized...
+                assert_allclose(result, array * kernel, atol=1e-14)
 
 
 class TestConvolve2D(object):
 
     @pytest.mark.parametrize(option_names, options)
-    def test_unity_1x1_none(self, boundary, interpolate_nan, normalize_kernel,
-                            ignore_edge_zeros):
+    def test_unity_1x1_none(self, boundary, nan_treatment, normalize_kernel):
         '''
         Test that a 1x1 unit kernel returns the same array
         '''
@@ -278,15 +383,13 @@ class TestConvolve2D(object):
         y = np.array([[1.]], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
-                         normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         nan_treatment=nan_treatment,
+                         normalize_kernel=normalize_kernel)
 
         assert_array_almost_equal_nulp(z, x, 10)
 
     @pytest.mark.parametrize(option_names, options)
-    def test_unity_3x3(self, boundary, interpolate_nan, normalize_kernel,
-                       ignore_edge_zeros):
+    def test_unity_3x3(self, boundary, nan_treatment, normalize_kernel):
         '''
         Test that a 3x3 unit kernel returns the same array (except when
         boundary is None).
@@ -301,16 +404,13 @@ class TestConvolve2D(object):
                       [0., 0., 0.]], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
-                         normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         nan_treatment=nan_treatment,
+                         normalize_kernel=normalize_kernel)
 
         assert_array_almost_equal_nulp(z, x, 10)
-        # assert np.all( np.abs(z-x) < np.spacing(np.where(z>x, z, x))*2 )
 
     @pytest.mark.parametrize(option_names, options)
-    def test_uniform_3x3(self, boundary, interpolate_nan, normalize_kernel,
-                         ignore_edge_zeros):
+    def test_uniform_3x3(self, boundary, nan_treatment, normalize_kernel):
         '''
         Test that the different modes are producing the correct results using
         a 3x3 uniform kernel.
@@ -325,9 +425,9 @@ class TestConvolve2D(object):
                       [1., 1., 1.]], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
-                         normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros)
+                         nan_treatment=nan_treatment,
+                         fill_value=np.nan if normalize_kernel else 0,
+                         normalize_kernel=normalize_kernel)
 
         w = np.array([[4., 6., 4.],
                       [6., 9., 6.],
@@ -352,7 +452,7 @@ class TestConvolve2D(object):
 
         if boundary == 'wrap':
             answer_key += '_wrap'
-        elif not ignore_edge_zeros:
+        elif nan_treatment == 'fill':
             answer_key += '_withzeros'
 
         a = answer_dict[answer_key]
@@ -360,9 +460,9 @@ class TestConvolve2D(object):
         # component that is EXACTLY 10*np.spacing
         assert np.all(np.abs(z - a) <= np.spacing(np.where(z > a, z, a)) * 10)
 
-    @pytest.mark.parametrize(option_names, options)
-    def test_unity_3x3_withnan(self, boundary, interpolate_nan,
-                               normalize_kernel, ignore_edge_zeros):
+    @pytest.mark.parametrize(option_names_preserve_nan, options_preserve_nan)
+    def test_unity_3x3_withnan(self, boundary, nan_treatment,
+                               normalize_kernel, preserve_nan):
         '''
         Test that a 3x3 unit kernel returns the same array (except when
         boundary is None). This version includes a NaN value in the original
@@ -378,10 +478,15 @@ class TestConvolve2D(object):
                       [0., 0., 0.]], dtype='float64')
 
         z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
+                         nan_treatment=nan_treatment,
                          normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros,
-                         )
+                         preserve_nan=preserve_nan)
+
+        if preserve_nan:
+            assert np.isnan(z[1, 1])
+
+        x = np.nan_to_num(z)
+        z = np.nan_to_num(z)
 
         a = x
         a[1, 1] = 0
@@ -391,11 +496,11 @@ class TestConvolve2D(object):
         if hasattr(np, 'float16'):
             assert_array_almost_equal_nulp(np.asarray(z, dtype=np.float16),
                                            np.asarray(a, dtype=np.float16), 10)
-        assert np.all(np.abs(z - a) < 1e-14)
+        assert_allclose(z, a, atol=1e-14)
 
-    @pytest.mark.parametrize(option_names, options)
-    def test_uniform_3x3_withnan(self, boundary, interpolate_nan,
-                                 normalize_kernel, ignore_edge_zeros):
+    @pytest.mark.parametrize(option_names_preserve_nan, options_preserve_nan)
+    def test_uniform_3x3_withnan(self, boundary, nan_treatment,
+                                 normalize_kernel, preserve_nan):
         '''
         Test that the different modes are producing the correct results using
         a 3x3 uniform kernel. This version includes a NaN value in the
@@ -410,12 +515,27 @@ class TestConvolve2D(object):
                       [1., 1., 1.],
                       [1., 1., 1.]], dtype='float64')
 
-        z = convolve_fft(x, y, boundary=boundary,
-                         interpolate_nan=interpolate_nan,
-                         normalize_kernel=normalize_kernel,
-                         ignore_edge_zeros=ignore_edge_zeros,
-                         )
+        # commented out: allow unnormalized nan-ignoring convolution
+        # # kernel is not normalized, so this situation -> exception
+        # if nan_treatment and not normalize_kernel:
+        #     with pytest.raises(ValueError):
+        #         z = convolve_fft(x, y, boundary=boundary,
+        #                          nan_treatment=nan_treatment,
+        #                          normalize_kernel=normalize_kernel,
+        #                          ignore_edge_zeros=ignore_edge_zeros,
+        #                          )
+        #     return
 
+        z = convolve_fft(x, y, boundary=boundary,
+                         nan_treatment=nan_treatment,
+                         fill_value=np.nan if normalize_kernel else 0,
+                         normalize_kernel=normalize_kernel,
+                         preserve_nan=preserve_nan)
+
+        if preserve_nan:
+            assert np.isnan(z[1, 1])
+
+        # weights
         w_n = np.array([[3., 5., 3.],
                         [5., 8., 5.],
                         [3., 5., 3.]], dtype='float64')
@@ -431,15 +551,15 @@ class TestConvolve2D(object):
                                   [6., 6., 6.]], dtype='float64'),
         }
         answer_dict['average'] = answer_dict['sum'] / w_z
-        answer_dict['average_ignan'] = answer_dict['sum'] / w_n
-        answer_dict['average_wrap_ignan'] = answer_dict['sum_wrap'] / 8.
+        answer_dict['average_interpnan'] = answer_dict['sum'] / w_n
+        answer_dict['average_wrap_interpnan'] = answer_dict['sum_wrap'] / 8.
         answer_dict['average_wrap'] = answer_dict['sum_wrap'] / 9.
         answer_dict['average_withzeros'] = answer_dict['sum'] / 9.
-        answer_dict['average_withzeros_ignan'] = answer_dict['sum'] / 8.
+        answer_dict['average_withzeros_interpnan'] = answer_dict['sum'] / 8.
         answer_dict['sum_withzeros'] = answer_dict['sum']
-        answer_dict['sum_ignan'] = answer_dict['sum']
-        answer_dict['sum_withzeros_ignan'] = answer_dict['sum']
-        answer_dict['sum_wrap_ignan'] = answer_dict['sum_wrap']
+        answer_dict['sum_interpnan'] = answer_dict['sum'] * 9/8.
+        answer_dict['sum_withzeros_interpnan'] = answer_dict['sum']
+        answer_dict['sum_wrap_interpnan'] = answer_dict['sum_wrap'] * 9/8.
 
         if normalize_kernel:
             answer_key = 'average'
@@ -448,24 +568,54 @@ class TestConvolve2D(object):
 
         if boundary == 'wrap':
             answer_key += '_wrap'
-        elif not ignore_edge_zeros:
+        elif nan_treatment == 'fill':
             answer_key += '_withzeros'
 
-        if interpolate_nan:
-            answer_key += '_ignan'
+        if nan_treatment == 'interpolate':
+            answer_key += '_interpnan'
 
         a = answer_dict[answer_key]
+
+        # Skip the NaN at [1, 1] when preserve_nan=True
+        posns = np.where(np.isfinite(z))
+
         # for reasons unknown, the Windows FFT returns an answer for the [0, 0]
         # component that is EXACTLY 10*np.spacing
-        assert np.all(np.abs(z - a) <= np.spacing(np.where(z > a, z, a)) * 10)
+        assert np.all(np.abs(z - a)[posns] <=
+                      np.spacing(np.where(z > a, z, a))[posns] * 10)
 
     def test_big_fail(self):
         """ Test that convolve_fft raises an exception if a too-large array is passed in """
 
         with pytest.raises((ValueError, MemoryError)):
             # while a good idea, this approach did not work; it actually writes to disk
-            #arr = np.memmap('file.np', mode='w+', shape=(512, 512, 512), dtype=np.complex)
+            # arr = np.memmap('file.np', mode='w+', shape=(512, 512, 512), dtype=np.complex)
             # this just allocates the memory but never touches it; it's better:
             arr = np.empty([512, 512, 512], dtype=np.complex)
             # note 512**3 * 16 bytes = 2.0 GB
             convolve_fft(arr, arr)
+
+    @pytest.mark.parametrize(('boundary'), BOUNDARY_OPTIONS)
+    def test_non_normalized_kernel(self, boundary):
+
+        x = np.array([[0., 0., 4.],
+                      [1., 2., 0.],
+                      [0., 3., 0.]], dtype='float')
+
+        y = np.array([[1., -1., 1.],
+                      [-1., 0., -1.],
+                      [1., -1., 1.]], dtype='float')
+
+        z = convolve_fft(x, y, boundary=boundary, nan_treatment='fill',
+                         normalize_kernel=False)
+
+        if boundary in (None, 'fill'):
+            assert_allclose(z, np.array([[1., -5., 2.],
+                                         [1., 0., -3.],
+                                         [-2., -1., -1.]], dtype='float'), atol=1e-14)
+        elif boundary == 'wrap':
+            assert_allclose(z, np.array([[0., -8., 6.],
+                                         [5., 0., -4.],
+                                         [2., 3., -4.]], dtype='float'), atol=1e-14)
+        else:
+            raise ValueError("Invalid boundary specification")
