@@ -4,11 +4,10 @@ from __future__ import (absolute_import, division, print_function,
 
 import itertools
 
+import pytest
 import numpy as np
 from numpy.testing import assert_allclose
 
-from ...tests.helper import pytest
-
 from ..utils import discretize_model
 from ...modeling.functional_models import (
     Gaussian1D, Box1D, MexicanHat1D, Gaussian2D, Box2D, MexicanHat2D)
@@ -74,21 +73,44 @@ def test_pixel_sum_2D(model_class, mode):
 def test_gaussian_eval_2D(mode):
     """
     Discretize Gaussian with different modes and check
-    if result is at least similar to Gaussian1D.eval()
+    if result is at least similar to Gaussian2D.eval()
     """
-    model = Gaussian2D(1, 0, 0, 20, 20)
-    x = np.arange(-100, 101)
-    y = np.arange(-100, 101)
+    model = Gaussian2D(0.01, 0, 0, 1, 1)
+
+    x = np.arange(-2, 3)
+    y = np.arange(-2, 3)
+
     x, y = np.meshgrid(x, y)
+
     values = model(x, y)
-    disc_values = discretize_model(model, (-100, 101), (-100, 101), mode=mode)
-    assert_allclose(values, disc_values, atol=0.001)
+    disc_values = discretize_model(model, (-2, 3), (-2, 3), mode=mode)
+    assert_allclose(values, disc_values, atol=1e-2)
+
+
+@pytest.mark.skipif('not HAS_SCIPY')
+def test_gaussian_eval_2D_integrate_mode():
+    """
+    Discretize Gaussian with integrate mode
+    """
+    model_list = [Gaussian2D(.01, 0, 0, 2, 2),
+                  Gaussian2D(.01, 0, 0, 1, 2),
+                  Gaussian2D(.01, 0, 0, 2, 1)]
+
+    x = np.arange(-2, 3)
+    y = np.arange(-2, 3)
+
+    x, y = np.meshgrid(x, y)
+
+    for model in model_list:
+        values = model(x, y)
+        disc_values = discretize_model(model, (-2, 3), (-2, 3), mode='integrate')
+        assert_allclose(values, disc_values, atol=1e-2)
 
 
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_subpixel_gauss_1D():
     """
-    Test subpixel accuracy of the oversample mode with gaussian 1D model.
+    Test subpixel accuracy of the integrate mode with gaussian 1D model.
     """
     gauss_1D = Gaussian1D(1, 0, 0.1)
     values = discretize_model(gauss_1D, (-1, 2), mode='integrate', factor=100)
@@ -98,12 +120,13 @@ def test_subpixel_gauss_1D():
 @pytest.mark.skipif('not HAS_SCIPY')
 def test_subpixel_gauss_2D():
     """
-    Test subpixel accuracy of the oversample mode with gaussian 2D model.
+    Test subpixel accuracy of the integrate mode with gaussian 2D model.
     """
     gauss_2D = Gaussian2D(1, 0, 0, 0.1, 0.1)
     values = discretize_model(gauss_2D, (-1, 2), (-1, 2), mode='integrate', factor=100)
     assert_allclose(values.sum(), 2 * np.pi * 0.01, atol=0.00001)
 
+
 def test_discretize_callable_1d():
     """
     Test discretize when a 1d function is passed.
@@ -113,6 +136,7 @@ def test_discretize_callable_1d():
     y = discretize_model(f, (-5, 6))
     assert_allclose(y, np.arange(-5, 6) ** 2)
 
+
 def test_discretize_callable_2d():
     """
     Test discretize when a 2d function is passed.
@@ -124,6 +148,7 @@ def test_discretize_callable_2d():
     desired = x ** 2 + y ** 2
     assert_allclose(actual, desired)
 
+
 def test_type_exception():
     """
     Test type exception.
@@ -132,6 +157,7 @@ def test_type_exception():
         discretize_model(float(0), (-10, 11))
     assert exc.value.args[0] == 'Model must be callable.'
 
+
 def test_dim_exception_1d():
     """
     Test dimension exception 1d.
@@ -142,6 +168,7 @@ def test_dim_exception_1d():
         discretize_model(f, (-10, 11), (-10, 11))
     assert exc.value.args[0] == "y range specified, but model is only 1-d."
 
+
 def test_dim_exception_2d():
     """
     Test dimension exception 2d.
@@ -152,6 +179,7 @@ def test_dim_exception_2d():
         discretize_model(f, (-10, 11))
     assert exc.value.args[0] == "y range not specified, but model is 2-d"
 
+
 def test_float_x_range_exception():
     def f(x, y):
         return x ** 2 + y ** 2
@@ -160,6 +188,7 @@ def test_float_x_range_exception():
     assert exc.value.args[0] == ("The difference between the upper an lower"
                                  " limit of 'x_range' must be a whole number.")
 
+
 def test_float_y_range_exception():
     def f(x, y):
         return x ** 2 + y ** 2
