@@ -11,6 +11,7 @@ from __future__ import (absolute_import, division, print_function,
 from .errors import *
 from .angles import *
 from .baseframe import *
+from .attributes import *
 from .distances import *
 from .earth import *
 from .transformations import *
@@ -23,6 +24,11 @@ from .funcs import *
 from .calculation import *
 from .solar_system import *
 
+# This is for backwards-compatibility -- can be removed in v3.0 when the
+# deprecation warnings are removed
+from .attributes import (TimeFrameAttribute, QuantityFrameAttribute,
+                         CartesianRepresentationFrameAttribute)
+
 __doc__ += builtin_frames._transform_graph_docs + """
 
 .. note::
