@@ -21,8 +21,6 @@ from ..utils import isiterable
 __all__ = ['Angle', 'Latitude', 'Longitude']
 
 
-TWOPI = math.pi * 2.0  # no need to calculate this all the time
-
 # these are used by the `hms` and `dms` attributes
 hms_tuple = namedtuple('hms_tuple', ('h', 'm', 's'))
 dms_tuple = namedtuple('dms_tuple', ('d', 'm', 's'))
@@ -44,7 +42,7 @@ class Angle(u.SpecificTypeQuantity):
       Angle('1:2:30.43 degrees')
       Angle('1 2 0 hours')
       Angle(np.arange(1, 8), unit=u.deg)
-      Angle(u'1°2′3″')
+      Angle('1°2′3″')
       Angle('1d2m3.4s')
       Angle('-1h2m3s')
       Angle('-1h2.5m')
@@ -359,12 +357,12 @@ class Angle(u.SpecificTypeQuantity):
           >>> import astropy.units as u
           >>> a = Angle([-20.0, 150.0, 350.0] * u.deg)
 
-          >>> a.wrap_at(360 * u.deg).degree  # Wrap into range 0 to 360 degrees
-          array([ 340.,  150.,  350.])
+          >>> a.wrap_at(360 * u.deg).degree  # Wrap into range 0 to 360 degrees  # doctest: +FLOAT_CMP
+          array([340., 150., 350.])
 
-          >>> a.wrap_at('180d', inplace=True)  # Wrap into range -180 to 180 degrees
-          >>> a.degree
-          array([ -20.,  150.,  -10.])
+          >>> a.wrap_at('180d', inplace=True)  # Wrap into range -180 to 180 degrees  # doctest: +FLOAT_CMP
+          >>> a.degree  # doctest: +FLOAT_CMP
+          array([-20., 150., -10.])
 
         Parameters
         ----------
@@ -433,7 +431,10 @@ class Angle(u.SpecificTypeQuantity):
         return bool(ok)
 
     def __str__(self):
-        return str(self.to_string())
+        if self.isscalar:
+            return str(self.to_string())
+        else:
+            return np.array2string(self, formatter={'all': lambda x: x.to_string()})
 
     def _repr_latex_(self):
         if self.isscalar:
@@ -441,8 +442,7 @@ class Angle(u.SpecificTypeQuantity):
         else:
             # Need to do a magic incantation to convert to str.  Regular str
             # or array2string causes all backslashes to get doubled.
-            return np.array2string(self.to_string(format='latex'),
-                                   formatter={'str_kind': lambda x: x})
+            return np.array2string(self, formatter={'all': lambda x: x.to_string(format='latex')})
 
 
 def _no_angle_subclass(obj):
