@@ -14,17 +14,16 @@ this package, like ``test_sky_coord.py``, ``test_frames.py``, or
 deviations from the original APE5 plan.
 """
 
+import pytest
 import numpy as np
 from numpy.random import randn
 from numpy import testing as npt
-from ...tests.helper import (pytest, quantity_allclose as allclose,
-                             assert_quantity_allclose as assert_allclose)
-raises = pytest.raises
 
+from ...tests.helper import (raises, quantity_allclose as allclose,
+                             assert_quantity_allclose as assert_allclose)
 from ... import units as u
 from ... import time
 from ... import coordinates as coords
-from ..errors import *
 
 try:
     import scipy  # pylint: disable=W0611
