@@ -9,20 +9,24 @@ from __future__ import (absolute_import, division, print_function,
 """Test initialization of angles not already covered by the API tests"""
 
 import pickle
+
+import pytest
 import numpy as np
 
 from ..earth import EarthLocation, ELLIPSOIDS
 from ..angles import Longitude, Latitude
-from ...tests.helper import pytest, quantity_allclose, remote_data
+from ...tests.helper import quantity_allclose, remote_data
 from ...extern.six.moves import zip
 from ... import units as u
 from ..name_resolve import NameResolveError
 
+
 def allclose_m14(a, b, rtol=1.e-14, atol=None):
     if atol is None:
         atol = 1.e-14 * getattr(a, 'unit', 1)
     return quantity_allclose(a, b, rtol, atol)
 
+
 def allclose_m8(a, b, rtol=1.e-8, atol=None):
     if atol is None:
         atol = 1.e-8 * getattr(a, 'unit', 1)
@@ -32,6 +36,7 @@ def allclose_m8(a, b, rtol=1.e-8, atol=None):
 def isclose_m14(val, ref):
     return np.array([allclose_m14(v, r) for (v, r) in zip(val, ref)])
 
+
 def isclose_m8(val, ref):
     return np.array([allclose_m8(v, r) for (v, r) in zip(val, ref)])
 
@@ -99,7 +104,7 @@ class TestInput():
         self.lon = Longitude([0., 45., 90., 135., 180., -180, -90, -45], u.deg,
                              wrap_angle=180*u.deg)
         self.lat = Latitude([+0., 30., 60., +90., -90., -60., -30., 0.], u.deg)
-        self.h = u.Quantity([0.1, 0.5, 1.0, -0.5, -1.0, +4.2, -11.,-.1], u.m)
+        self.h = u.Quantity([0.1, 0.5, 1.0, -0.5, -1.0, +4.2, -11., -.1], u.m)
         self.location = EarthLocation.from_geodetic(self.lon, self.lat, self.h)
         self.x, self.y, self.z = self.location.to_geocentric()
 
@@ -119,8 +124,8 @@ class TestInput():
         assert type(self.location.x) is u.Quantity
         assert type(self.location.y) is u.Quantity
         assert type(self.location.z) is u.Quantity
-        assert type(self.location.longitude) is Longitude
-        assert type(self.location.latitude) is Latitude
+        assert type(self.location.lon) is Longitude
+        assert type(self.location.lat) is Latitude
         assert type(self.location.height) is u.Quantity
 
     def test_input(self):
@@ -134,22 +139,22 @@ class TestInput():
         assert np.all(geocentric2 == self.location)
         geodetic = EarthLocation(self.lon, self.lat, self.h)
         assert np.all(geodetic == self.location)
-        geodetic2 = EarthLocation(self.lon.to(u.degree).value,
-                                  self.lat.to(u.degree).value,
-                                  self.h.to(u.m).value)
+        geodetic2 = EarthLocation(self.lon.to_value(u.degree),
+                                  self.lat.to_value(u.degree),
+                                  self.h.to_value(u.m))
         assert np.all(geodetic2 == self.location)
         geodetic3 = EarthLocation(self.lon, self.lat)
-        assert allclose_m14(geodetic3.longitude.value,
-                            self.location.longitude.value)
-        assert allclose_m14(geodetic3.latitude.value,
-                            self.location.latitude.value)
+        assert allclose_m14(geodetic3.lon.value,
+                            self.location.lon.value)
+        assert allclose_m14(geodetic3.lat.value,
+                            self.location.lat.value)
         assert not np.any(isclose_m14(geodetic3.height.value,
                                       self.location.height.value))
         geodetic4 = EarthLocation(self.lon, self.lat, self.h[-1])
-        assert allclose_m14(geodetic4.longitude.value,
-                            self.location.longitude.value)
-        assert allclose_m14(geodetic4.latitude.value,
-                            self.location.latitude.value)
+        assert allclose_m14(geodetic4.lon.value,
+                            self.location.lon.value)
+        assert allclose_m14(geodetic4.lat.value,
+                            self.location.lat.value)
         assert allclose_m14(geodetic4.height[-1].value,
                             self.location.height[-1].value)
         assert not np.any(isclose_m14(geodetic4.height[:-1].value,
@@ -159,12 +164,12 @@ class TestInput():
         assert geocentric5.unit is u.pc
         assert geocentric5.x.unit is u.pc
         assert geocentric5.height.unit is u.pc
-        assert allclose_m14(geocentric5.x.to(self.x.unit).value, self.x.value)
+        assert allclose_m14(geocentric5.x.to_value(self.x.unit), self.x.value)
         geodetic5 = EarthLocation(self.lon, self.lat, self.h.to(u.pc))
         assert geodetic5.unit is u.pc
         assert geodetic5.x.unit is u.pc
         assert geodetic5.height.unit is u.pc
-        assert allclose_m14(geodetic5.x.to(self.x.unit).value, self.x.value)
+        assert allclose_m14(geodetic5.x.to_value(self.x.unit), self.x.value)
 
     def test_invalid_input(self):
         """Check invalid input raises exception"""
@@ -252,6 +257,18 @@ class TestInput():
         else:
             assert not np.all(isclose_m14(location.z.value, self.z.value))
 
+        def test_to_value(self):
+            loc = self.location
+            loc_ndarray = loc.view(np.ndarray)
+            assert np.all(loc.value == loc_ndarray)
+            loc2 = self.location.to(u.km)
+            loc2_ndarray = np.empty_like(loc_ndarray)
+            for coo in 'x', 'y', 'z':
+                loc2_ndarray[coo] = loc_ndarray[coo] / 1000.
+            assert np.all(loc2.value == loc2_ndarray)
+            loc2_value = self.location.to_value(u.km)
+            assert np.all(loc2_value == loc2_ndarray)
+
 
 def test_pickling():
     """Regression test against #4304."""
@@ -260,6 +277,7 @@ def test_pickling():
     el2 = pickle.loads(s)
     assert el == el2
 
+
 def test_repr_latex():
     """
     Regression test for issue #4542
@@ -278,12 +296,27 @@ def test_of_address():
 
     # just a location
     loc = EarthLocation.of_address("New York, NY")
-    assert quantity_allclose(loc.latitude, 40.7128*u.degree)
-    assert quantity_allclose(loc.longitude, -74.0059*u.degree)
+    assert quantity_allclose(loc.lat, 40.7128*u.degree)
+    assert quantity_allclose(loc.lon, -74.0059*u.degree)
     assert np.allclose(loc.height.value, 0.)
 
     # a location and height
     loc = EarthLocation.of_address("New York, NY", get_height=True)
-    assert quantity_allclose(loc.latitude, 40.7128*u.degree)
-    assert quantity_allclose(loc.longitude, -74.0059*u.degree)
+    assert quantity_allclose(loc.lat, 40.7128*u.degree)
+    assert quantity_allclose(loc.lon, -74.0059*u.degree)
     assert quantity_allclose(loc.height, 10.438659669*u.meter, atol=1.*u.cm)
+
+
+def test_geodetic_tuple():
+    lat = 2*u.deg
+    lon = 10*u.deg
+    height = 100*u.m
+
+    el = EarthLocation.from_geodetic(lat=lat, lon=lon, height=height)
+
+    res1 = el.to_geodetic()
+    res2 = el.geodetic
+
+    assert res1.lat == res2.lat and quantity_allclose(res1.lat, lat)
+    assert res1.lon == res2.lon and quantity_allclose(res1.lon, lon)
+    assert res1.height == res2.height and quantity_allclose(res1.height, height)
