@@ -17,7 +17,7 @@ from collections import defaultdict, OrderedDict
 
 from . import core
 from . import fixedwidth
-from ...extern.six.moves import zip, map
+from ...extern.six.moves import zip, map, range
 from .misc import first_true_index, first_false_index, groupmore
 
 
@@ -29,7 +29,7 @@ class DaophotHeader(core.BaseHeader):
     comment = r'\s*#K'
 
     # Regex for extracting the format strings
-    re_format = re.compile('%-?(\d+)\.?\d?[sdfg]')
+    re_format = re.compile(r'%-?(\d+)\.?\d?[sdfg]')
     re_header_keyword = re.compile(r'[#]K'
                                    r'\s+ (?P<name> \w+)'
                                    r'\s* = (?P<stuff> .+) $',
@@ -154,7 +154,7 @@ class DaophotHeader(core.BaseHeader):
 
         Parameters
         ----------
-        lines: list
+        lines : list
             List of table lines
 
         Returns
@@ -278,13 +278,13 @@ class DaophotInputter(core.ContinuationLinesInputter):
     def process_lines(self, lines):
 
         markers, block, header = self.search_multiline(lines)
-        self.data.is_multiline = not markers is None
+        self.data.is_multiline = markers is not None
         self.data.markers = markers
         self.data.first_block = block
         # set the header lines returned by the search as a attribute of the header
         self.data.header.lines = header
 
-        if not markers is None:
+        if markers is not None:
             lines = lines[markers[0]:]
 
         continuation_char = self.continuation_char
@@ -308,7 +308,8 @@ class DaophotInputter(core.ContinuationLinesInputter):
                     outlines.append(''.join(parts))
                     parts = []
             else:
-                raise ValueError('multiline re could not match line %i: %s' % (i, line))
+                raise ValueError('multiline re could not match line '
+                                 '{}: {}'.format(i, line))
 
         return outlines
 
