@@ -5,8 +5,6 @@ relevant to FITS) or that otherwise require workarounds.
 """
 
 
-
-
 def realign_dtype(dtype, offsets):
     """
     Given a Numpy struct dtype object an a list of integer offsets, with one
@@ -43,8 +41,8 @@ def realign_dtype(dtype, offsets):
     names, fields = state[3:5]
     fields = fields.copy()
 
-    max_offset = 0
-    itemsize = state[5]  # Default to the original itemsize
+    itemsize = 0  # We will re-determine the itemsize based on the type
+                  # of the field with the largest (offset + itemsize)
 
     if fields is None or len(offsets) != len(names):
         raise ValueError(
@@ -53,14 +51,10 @@ def realign_dtype(dtype, offsets):
 
     for name, offset in zip(names, offsets):
         field = fields[name]
-        if offset == field[1]:
-            continue
+        itemsize = max(itemsize, offset + field[0].itemsize)
 
-        fields[name] = (field[0], offset)
-
-        if offset > max_offset:
-            itemsize = offset + field[0].itemsize
-            max_offset = offset
+        if offset != field[1]:
+            fields[name] = (field[0], offset)
 
     new_typespec = '|V{0}'.format(itemsize)
 
