@@ -868,11 +868,10 @@ class ImageDataDiff(_BaseDiff):
             return
 
         # Find the indices where the values are not equal
-        # If neither a nor b are floating point, ignore rtol and atol
-        if not ((np.issubdtype(self.a.dtype, float) or
-                 np.issubdtype(self.a.dtype, complex)) or
-                (np.issubdtype(self.b.dtype, float) or
-                 np.issubdtype(self.b.dtype, complex))):
+        # If neither a nor b are floating point (or complex), ignore rtol and
+        # atol
+        if not (np.issubdtype(self.a.dtype, np.inexact) or
+                np.issubdtype(self.b.dtype, np.inexact)):
             rtol = 0
             atol = 0
         else:
@@ -1157,7 +1156,7 @@ class TableDataDiff(_BaseDiff):
 
         # Like in the old fitsdiff, compare tables on a column by column basis
         # The difficulty here is that, while FITS column names are meant to be
-        # case-insensitive, PyFITS still allows, for the sake of flexibility,
+        # case-insensitive, Astropy still allows, for the sake of flexibility,
         # two columns with the same name but different case.  When columns are
         # accessed in FITS tables, a case-sensitive is tried first, and failing
         # that a case-insensitive match is made.
@@ -1184,8 +1183,8 @@ class TableDataDiff(_BaseDiff):
             arra = self.a[col.name]
             arrb = self.b[col.name]
 
-            if (np.issubdtype(arra.dtype, float) and
-                    np.issubdtype(arrb.dtype, float)):
+            if (np.issubdtype(arra.dtype, np.floating) and
+                    np.issubdtype(arrb.dtype, np.floating)):
                 diffs = where_not_allclose(arra, arrb,
                                            rtol=self.rtol,
                                            atol=self.atol)
