@@ -1,8 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 import io
-from ....tests.helper import pytest
 
+import pytest
 import numpy as np
 
 from ..column import Column
@@ -108,8 +108,7 @@ class TestDiff(FitsTestCase):
         assert ("Inconsistent duplicates of keyword 'A'     :\n"
                 "  Occurs 3 time(s) in a, 1 times in (b)") in report
 
-
-    def test_floating_point_tolerance(self):
+    def test_floating_point_rtol(self):
         ha = Header([('A', 1), ('B', 2.00001), ('C', 3.000001)])
         hb = ha.copy()
         hb['B'] = 2.00002
@@ -118,9 +117,66 @@ class TestDiff(FitsTestCase):
         assert not diff.identical
         assert (diff.diff_keyword_values ==
                 {'B': [(2.00001, 2.00002)], 'C': [(3.000001, 3.000002)]})
-        diff = HeaderDiff(ha, hb, tolerance=1e-6)
+        diff = HeaderDiff(ha, hb, rtol=1e-6)
         assert not diff.identical
         assert diff.diff_keyword_values == {'B': [(2.00001, 2.00002)]}
+        diff = HeaderDiff(ha, hb, rtol=1e-5)
+        assert diff.identical
+
+    def test_floating_point_atol(self):
+        ha = Header([('A', 1), ('B', 1.0), ('C', 0.0)])
+        hb = ha.copy()
+        hb['B'] = 1.00001
+        hb['C'] = 0.000001
+        diff = HeaderDiff(ha, hb, rtol=1e-6)
+        assert not diff.identical
+        assert (diff.diff_keyword_values ==
+                {'B': [(1.0, 1.00001)], 'C': [(0.0, 0.000001)]})
+        diff = HeaderDiff(ha, hb, rtol=1e-5)
+        assert not diff.identical
+        assert (diff.diff_keyword_values ==
+                {'C': [(0.0, 0.000001)]})
+        diff = HeaderDiff(ha, hb, atol=1e-6)
+        assert not diff.identical
+        assert (diff.diff_keyword_values ==
+                {'B': [(1.0, 1.00001)]})
+        diff = HeaderDiff(ha, hb, atol=1e-5)  # strict inequality
+        assert not diff.identical
+        assert (diff.diff_keyword_values ==
+                {'B': [(1.0, 1.00001)]})
+        diff = HeaderDiff(ha, hb, rtol=1e-5, atol=1e-5)
+        assert diff.identical
+        diff = HeaderDiff(ha, hb, atol=1.1e-5)
+        assert diff.identical
+        diff = HeaderDiff(ha, hb, rtol=1e-6, atol=1e-6)
+        assert not diff.identical
+
+    def test_deprecation_tolerance(self):
+        """Verify uses of tolerance and rtol.
+        This test should be removed in the next astropy version."""
+
+        ha = Header([('B', 1.0), ('C', 0.1)])
+        hb = ha.copy()
+        hb['B'] = 1.00001
+        hb['C'] = 0.100001
+        with catch_warnings(AstropyDeprecationWarning) as warning_lines:
+            diff = HeaderDiff(ha, hb, tolerance=1e-6)
+            assert warning_lines[0].category == AstropyDeprecationWarning
+            assert (str(warning_lines[0].message) == '"tolerance" was '
+                    'deprecated in version 2.0 and will be removed in a '
+                    'future version. Use argument "rtol" instead.')
+            assert (diff.diff_keyword_values == {'C': [(0.1, 0.100001)],
+                                                 'B': [(1.0, 1.00001)]})
+            assert not diff.identical
+
+        with catch_warnings(AstropyDeprecationWarning) as warning_lines:
+            # `rtol` is always ignored when `tolerance` is provided
+            diff = HeaderDiff(ha, hb, rtol=1e-6, tolerance=1e-5)
+            assert warning_lines[0].category == AstropyDeprecationWarning
+            assert (str(warning_lines[0].message) == '"tolerance" was '
+                    'deprecated in version 2.0 and will be removed in a '
+                    'future version. Use argument "rtol" instead.')
+            assert diff.identical
 
     def test_ignore_blanks(self):
         with fits.conf.set_temp('strip_header_whitespace', False):
@@ -217,13 +273,37 @@ class TestDiff(FitsTestCase):
         assert diff.identical
         assert diff.diff_total == 0
 
-    def test_identical_within_tolerance(self):
+    def test_identical_within_relative_tolerance(self):
         ia = np.ones((10, 10)) - 0.00001
         ib = np.ones((10, 10)) - 0.00002
-        diff = ImageDataDiff(ia, ib, tolerance=1.0e-4)
+        diff = ImageDataDiff(ia, ib, rtol=1.0e-4)
         assert diff.identical
         assert diff.diff_total == 0
 
+    def test_identical_within_absolute_tolerance(self):
+        ia = np.zeros((10, 10)) - 0.00001
+        ib = np.zeros((10, 10)) - 0.00002
+        diff = ImageDataDiff(ia, ib, rtol=1.0e-4)
+        assert not diff.identical
+        assert diff.diff_total == 100
+        diff = ImageDataDiff(ia, ib, atol=1.0e-4)
+        assert diff.identical
+        assert diff.diff_total == 0
+
+    def test_identical_within_rtol_and_atol(self):
+        ia = np.zeros((10, 10)) - 0.00001
+        ib = np.zeros((10, 10)) - 0.00002
+        diff = ImageDataDiff(ia, ib, rtol=1.0e-5, atol=1.0e-5)
+        assert diff.identical
+        assert diff.diff_total == 0
+
+    def test_not_identical_within_rtol_and_atol(self):
+        ia = np.zeros((10, 10)) - 0.00001
+        ib = np.zeros((10, 10)) - 0.00002
+        diff = ImageDataDiff(ia, ib, rtol=1.0e-5, atol=1.0e-6)
+        assert not diff.identical
+        assert diff.diff_total == 100
+
     def test_identical_comp_image_hdus(self):
         """Regression test for https://aeon.stsci.edu/ssb/trac/pyfits/ticket/189
 
@@ -730,5 +810,5 @@ class TestDiff(FitsTestCase):
             diffobj.report(fileobj=outpath, clobber=True)
             assert warning_lines[0].category == AstropyDeprecationWarning
             assert (str(warning_lines[0].message) == '"clobber" was '
-                    'deprecated in version 1.3 and will be removed in a '
+                    'deprecated in version 2.0 and will be removed in a '
                     'future version. Use argument "overwrite" instead.')
