@@ -12,9 +12,13 @@ import os
 import warnings
 
 import numpy as np
+
+# NOTE: Do not import anything from astropy.table here.
+# https://github.com/astropy/astropy/issues/6604
+
 from ...utils.exceptions import AstropyUserWarning
 from ...extern import six
-from ...table import meta
+
 
 HDF5_SIGNATURE = b'\x89HDF\r\n\x1a\n'
 META_KEY = '__table_column_meta__'
@@ -60,7 +64,7 @@ def read_table_hdf5(input, path=None):
     """
     Read a Table object from an HDF5 file
 
-    This requires `h5py <http://h5py.org/>`_ to be installed. If more than one
+    This requires `h5py <http://www.h5py.org/>`_ to be installed. If more than one
     table is present in the HDF5 file or group, the first table is read in and
     a warning is displayed.
 
@@ -136,7 +140,8 @@ def read_table_hdf5(input, path=None):
     # convert to a Table.
 
     # Create a Table object
-    from ...table import Table
+    from ...table import Table, meta
+
     table = Table(np.array(input))
 
     # Read the meta-data from the file
@@ -163,7 +168,7 @@ def write_table_hdf5(table, output, path=None, compression=False,
     """
     Write a Table object to an HDF5 file
 
-    This requires `h5py <http://h5py.org/>`_ to be installed.
+    This requires `h5py <http://www.h5py.org/>`_ to be installed.
 
     Parameters
     ----------
@@ -188,6 +193,7 @@ def write_table_hdf5(table, output, path=None, compression=False,
         If ``append=True`` and ``overwrite=True`` then only the dataset will be
         replaced; the file/group will not be overwritten.
     """
+    from ...table import meta
 
     try:
         import h5py
@@ -283,3 +289,15 @@ def write_table_hdf5(table, output, path=None, compression=False,
                               "HDF5 files - skipping. (Consider specifying "
                               "serialize_meta=True to write all meta data)".format(key, type(val)),
                               AstropyUserWarning)
+
+
+def register_hdf5():
+    """
+    Register HDF5 with Unified I/O.
+    """
+    from .. import registry as io_registry
+    from ...table import Table
+
+    io_registry.register_reader('hdf5', Table, read_table_hdf5)
+    io_registry.register_writer('hdf5', Table, write_table_hdf5)
+    io_registry.register_identifier('hdf5', Table, is_hdf5)
