@@ -241,6 +241,28 @@ def register_reader(data_format, data_class, function, force=False):
         _update__doc__(data_class, 'read')
 
 
+def unregister_reader(data_format, data_class):
+    """
+    Unregister a reader function
+
+    Parameters
+    ----------
+    data_format : str
+        The data format identifier.
+    data_class : classobj
+        The class of the object that the reader produces.
+    """
+
+    if (data_format, data_class) in _readers:
+        _readers.pop((data_format, data_class))
+    else:
+        raise IORegistryError("No reader defined for format '{0}' and class '{1}'"
+                              ''.format(data_format, data_class.__name__))
+
+    if data_class not in _delayed_docs_classes:
+        _update__doc__(data_class, 'read')
+
+
 def register_writer(data_format, data_class, function, force=False):
     """
     Register a table writer function.
@@ -270,6 +292,28 @@ def register_writer(data_format, data_class, function, force=False):
         _update__doc__(data_class, 'write')
 
 
+def unregister_writer(data_format, data_class):
+    """
+    Unregister a writer function
+
+    Parameters
+    ----------
+    data_format : str
+        The data format identifier.
+    data_class : classobj
+        The class of the object that can be written.
+    """
+
+    if (data_format, data_class) in _writers:
+        _writers.pop((data_format, data_class))
+    else:
+        raise IORegistryError("No writer defined for format '{0}' and class '{1}'"
+                              ''.format(data_format, data_class.__name__))
+
+    if data_class not in _delayed_docs_classes:
+        _update__doc__(data_class, 'write')
+
+
 def register_identifier(data_format, data_class, identifier, force=False):
     """
     Associate an identifier function with a specific data type.
@@ -324,6 +368,25 @@ def register_identifier(data_format, data_class, identifier, force=False):
                                                        data_class.__name__))
 
 
+def unregister_identifier(data_format, data_class):
+    """
+    Unregister an identifier function
+
+    Parameters
+    ----------
+    data_format : str
+        The data format identifier.
+    data_class : classobj
+        The class of the object that can be read/written.
+    """
+
+    if (data_format, data_class) in _identifiers:
+        _identifiers.pop((data_format, data_class))
+    else:
+        raise IORegistryError("No identifier defined for format '{0}' and class"
+                              " '{1}'".format(data_format, data_class.__name__))
+
+
 def identify_format(origin, data_class_required, path, fileobj, args, kwargs):
     """Loop through identifiers to see which formats match.
 
@@ -523,15 +586,19 @@ def _is_best_match(class1, class2, format_classes):
     Determine if class2 is the "best" match for class1 in the list
     of classes.  It is assumed that (class2 in classes) is True.
     class2 is the the best match if:
-      - class1 is class2 => class1 was directly registered.
-      - OR class1 is a subclass of class2 and class1 is not in classes.
-        In this case the subclass will use the parent reader/writer.
+
+    - ``class1`` is a subclass of ``class2`` AND
+    - ``class2`` is the nearest ancestor of ``class1`` that is in classes
+      (which includes the case that ``class1 is class2``)
     """
-    # The set with the classes is only created if class1 is not class2 and
-    # class1 is a subclass of class2.
-    return (class1 is class2 or
-            (issubclass(class1, class2) and
-             class1 not in {cls for fmt, cls in format_classes}))
+    if issubclass(class1, class2):
+        classes = {cls for fmt, cls in format_classes}
+        for parent in class1.__mro__:
+            if parent is class2:  # class2 is closest registered ancestor
+                return True
+            if parent in classes:  # class2 was superceded
+                return False
+    return False
 
 
 def _get_valid_format(mode, cls, path, fileobj, args, kwargs):
