@@ -157,13 +157,17 @@ def test_write_with_format():
 
     output = io.BytesIO()
     t.write(output, format='votable', tabledata_format="binary")
-    assert b'BINARY' in output.getvalue()
-    assert b'TABLEDATA' not in output.getvalue()
+    obuff = output.getvalue()
+    assert b'VOTABLE version="1.3"' in obuff
+    assert b'BINARY' in obuff
+    assert b'TABLEDATA' not in obuff
 
     output = io.BytesIO()
     t.write(output, format='votable', tabledata_format="binary2")
-    assert b'BINARY2' in output.getvalue()
-    assert b'TABLEDATA' not in output.getvalue()
+    obuff = output.getvalue()
+    assert b'VOTABLE version="1.3"' in obuff
+    assert b'BINARY2' in obuff
+    assert b'TABLEDATA' not in obuff
 
 
 def test_empty_table():
