@@ -17,31 +17,45 @@ import operator
 
 import numpy as np
 
+from .. import units as u
+from ..units import Quantity, UnitsError
 from ..utils import isiterable, OrderedDescriptor
 from ..extern import six
 from ..extern.six.moves import zip
+from .utils import array_repr_oneline
 
 from .utils import get_inputs_and_params
 
-__all__ = ['Parameter', 'InputParameterError']
+__all__ = ['Parameter', 'InputParameterError', 'ParameterError']
 
 
-class InputParameterError(ValueError):
+class ParameterError(Exception):
+    """Generic exception class for all exceptions pertaining to Parameters."""
+
+
+class InputParameterError(ValueError, ParameterError):
     """Used for incorrect input parameter values and definitions."""
 
 
+class ParameterDefinitionError(ParameterError):
+    """Exception in declaration of class-level Parameters."""
+
+
 def _tofloat(value):
     """Convert a parameter to float or float array"""
 
     if isiterable(value):
         try:
-            value = np.array(value, dtype=np.float)
+            value = np.asanyarray(value, dtype=np.float)
         except (TypeError, ValueError):
             # catch arrays with strings or user errors like different
             # types of parameters in a parameter set
             raise InputParameterError(
                 "Parameter of {0} could not be converted to "
                 "float".format(type(value)))
+    elif isinstance(value, Quantity):
+        # Quantities are fine as is
+        pass
     elif isinstance(value, np.ndarray):
         # A scalar/dimensionless array
         value = float(value.item())
@@ -66,10 +80,15 @@ def _binary_arithmetic_operation(op, reflected=False):
         if self._model is None:
             return NotImplemented
 
-        if reflected:
-            return op(val, self.value)
+        if self.unit is not None:
+            self_value = Quantity(self.value, self.unit)
         else:
-            return op(self.value, val)
+            self_value = self.value
+
+        if reflected:
+            return op(val, self_value)
+        else:
+            return op(self_value, val)
 
     return wrapper
 
@@ -87,7 +106,12 @@ def _binary_comparison_operation(op):
             else:
                 return NotImplemented
 
-        return op(self.value, val)
+        if self.unit is not None:
+            self_value = Quantity(self.value, self.unit)
+        else:
+            self_value = self.value
+
+        return op(self_value, val)
 
     return wrapper
 
@@ -98,7 +122,12 @@ def _unary_arithmetic_operation(op):
         if self._model is None:
             return NotImplemented
 
-        return op(self.value)
+        if self.unit is not None:
+            self_value = Quantity(self.value, self.unit)
+        else:
+            self_value = self.value
+
+        return op(self_value)
 
     return wrapper
 
@@ -142,6 +171,10 @@ class Parameter(OrderedDescriptor):
         parameter description
     default : float or array
         default value to use for this parameter
+    unit : `~astropy.units.Unit`
+        if specified, the parameter will be in these units, and when the
+        parameter is updated in future, it should be set to a
+        :class:`~astropy.units.Quantity` that has equivalent units.
     getter : callable
         a function that wraps the raw (internal) value of the parameter
         when returning the value through the parameter proxy (eg. a
@@ -180,14 +213,26 @@ class Parameter(OrderedDescriptor):
     _class_attribute_ = '_parameters_'
     _name_attribute_ = '_name'
 
-    def __init__(self, name='', description='', default=None, getter=None,
-                 setter=None, fixed=False, tied=False, min=None, max=None,
-                 bounds=None, model=None):
+    def __init__(self, name='', description='', default=None, unit=None,
+                 getter=None, setter=None, fixed=False, tied=False, min=None,
+                 max=None, bounds=None, model=None):
         super(Parameter, self).__init__()
 
         self._name = name
         self.__doc__ = self._description = description.strip()
+
+        # We only need to perform this check on unbound parameters
+        if model is None and isinstance(default, Quantity):
+            if unit is not None and not unit.is_equivalent(default.unit):
+                raise ParameterDefinitionError(
+                    "parameter default {0} does not have units equivalent to "
+                    "the required unit {1}".format(default, unit))
+
+            unit = default.unit
+            default = default.value
+
         self._default = default
+        self._unit = unit
 
         # NOTE: These are *default* constraints--on model instances constraints
         # are taken from the model if set, otherwise the defaults set here are
@@ -235,16 +280,34 @@ class Parameter(OrderedDescriptor):
         return parameter
 
     def __set__(self, obj, value):
+
         value = _tofloat(value)
 
+        # Check that units are compatible with default or units already set
+        param_unit = obj._param_metrics[self.name]['orig_unit']
+        if param_unit is None:
+            if isinstance(value, Quantity):
+                obj._param_metrics[self.name]['orig_unit'] = value.unit
+        else:
+            if not isinstance(value, Quantity):
+                raise UnitsError("The '{0}' parameter should be given as a "
+                                 "Quantity because it was originally initialized "
+                                 "as a Quantity".format(self._name))
+            else:
+                # We need to make sure we update the unit because the units are
+                # then dropped from the value below.
+                obj._param_metrics[self.name]['orig_unit'] = value.unit
+
         # Call the validator before the setter
         if self._validator is not None:
             self._validator(obj, value)
 
         if self._setter is not None:
             setter = self._create_value_wrapper(self._setter, obj)
-            value = setter(value)
-
+            if self.unit is not None:
+                value = setter(value * self.unit).value
+            else:
+                value = setter(value)
         self._set_model_value(obj, value)
 
     def __len__(self):
@@ -266,7 +329,7 @@ class Parameter(OrderedDescriptor):
         oldvalue = self.value
         n_models = len(self._model)
 
-        #if n_models == 1:
+        # if n_models == 1:
         #    # Convert the single-dimension value to a list to allow some slices
         #    # that would be compatible with a length-1 array like [:] and [0:]
         #    oldvalue = [oldvalue]
@@ -294,6 +357,9 @@ class Parameter(OrderedDescriptor):
         else:
             args += ', value={0}'.format(self.value)
 
+        if self.unit is not None:
+            args += ', unit={0}'.format(self.unit)
+
         for cons in self.constraints:
             val = getattr(self, cons)
             if val not in (None, False, (None, None)):
@@ -339,17 +405,21 @@ class Parameter(OrderedDescriptor):
 
     @property
     def value(self):
-        """The unadorned value proxied by this parameter"""
+        """The unadorned value proxied by this parameter."""
 
         if self._model is None:
             raise AttributeError('Parameter definition does not have a value')
 
         value = self._get_model_value(self._model)
-
         if self._getter is None:
             return value
         else:
-            return self._getter(value)
+            raw_unit = self._model._param_metrics[self.name]['raw_unit']
+            orig_unit = self._model._param_metrics[self.name]['orig_unit']
+            if raw_unit is not None:
+                return np.float64(self._getter(value, raw_unit, orig_unit).value)
+            else:
+                return self._getter(value)
 
     @value.setter
     def value(self, value):
@@ -360,8 +430,68 @@ class Parameter(OrderedDescriptor):
         if self._setter is not None:
             val = self._setter(value)
 
+        if isinstance(value, Quantity):
+            raise TypeError("The .value property on parameters should be set to "
+                            "unitless values, not Quantity objects. To set a "
+                            "parameter to a quantity simply set the parameter "
+                            "directly without using .value")
         self._set_model_value(self._model, value)
 
+    @property
+    def unit(self):
+        """
+        The unit attached to this parameter, if any.
+
+        On unbound parameters (i.e. parameters accessed through the
+        model class, rather than a model instance) this is the required/
+        default unit for the parameter.
+        """
+
+        if self._model is None:
+            return self._unit
+        else:
+            # orig_unit may be undefined early on in model instantiation
+            return self._model._param_metrics[self.name].get('orig_unit',
+                                                             self._unit)
+
+    @unit.setter
+    def unit(self, unit):
+        self._set_unit(unit)
+
+    def _set_unit(self, unit, force=False):
+
+        if self._model is None:
+            raise AttributeError('Cannot set unit on a parameter definition')
+
+        orig_unit = self._model._param_metrics[self.name]['orig_unit']
+
+        if force:
+            self._model._param_metrics[self.name]['orig_unit'] = unit
+        else:
+            if orig_unit is None:
+                raise ValueError('Cannot attach units to parameters that were '
+                                 'not initially specified with units')
+            else:
+                raise ValueError('Cannot change the unit attribute directly, '
+                                 'instead change the parameter to a new quantity')
+
+    @property
+    def quantity(self):
+        """
+        This parameter, as a :class:`~astropy.units.Quantity` instance.
+        """
+        if self.unit is not None:
+            return self.value * self.unit
+        else:
+            return None
+
+    @quantity.setter
+    def quantity(self, quantity):
+        if not isinstance(quantity, Quantity):
+            raise TypeError("The .quantity attribute should be set to a Quantity object")
+        self.value = quantity.value
+        self._set_unit(quantity.unit, force=True)
+
     @property
     def shape(self):
         """The shape of this parameter's value array."""
@@ -583,9 +713,9 @@ class Parameter(OrderedDescriptor):
             else:
                 return types.MethodType(validator, self)
 
-    def copy(self, name=None, description=None, default=None, getter=None,
-             setter=None, fixed=False, tied=False, min=None, max=None,
-             bounds=None):
+    def copy(self, name=None, description=None, default=None, unit=None,
+             getter=None, setter=None, fixed=False, tied=False, min=None,
+             max=None, bounds=None):
         """
         Make a copy of this `Parameter`, overriding any of its core attributes
         in the process (or an exact copy).
@@ -644,6 +774,9 @@ class Parameter(OrderedDescriptor):
         self._getter = self._create_value_wrapper(self._getter, model)
         self._setter = self._create_value_wrapper(self._setter, model)
 
+    # TODO: These methods should probably be moved to the Model class, since it
+    # has entirely to do with details of how the model stores parameters.
+    # Parameter should just act as a user front-end to this.
     def _get_model_value(self, model):
         """
         This method implements how to retrieve the value of this parameter from
@@ -661,13 +794,15 @@ class Parameter(OrderedDescriptor):
 
         # Use the _param_metrics to extract the parameter value from the
         # _parameters array
-        param_slice = model._param_metrics[self._name]['slice']
-        param_shape = model._param_metrics[self._name]['shape']
+        param_metrics = model._param_metrics[self._name]
+        param_slice = param_metrics['slice']
+        param_shape = param_metrics['shape']
         value = model._parameters[param_slice]
         if param_shape:
             value = value.reshape(param_shape)
         else:
             value = value[0]
+
         return value
 
     def _set_model_value(self, model, value):
@@ -679,18 +814,24 @@ class Parameter(OrderedDescriptor):
         array) but other mechanisms may be desireable, in which case really the
         model class itself should dictate this and *not* `Parameter` itself.
         """
+        def _update_parameter_value(model, name, value):
+            # TODO: Maybe handle exception on invalid input shape
+            param_metrics = model._param_metrics[name]
+            param_slice = param_metrics['slice']
+            param_shape = param_metrics['shape']
+            param_size = np.prod(param_shape)
 
-        # TODO: Maybe handle exception on invalid input shape
-        param_slice = model._param_metrics[self._name]['slice']
-        param_shape = model._param_metrics[self._name]['shape']
-        param_size = np.prod(param_shape)
+            if np.size(value) != param_size:
+                raise InputParameterError(
+                    "Input value for parameter {0!r} does not have {1} elements "
+                    "as the current value does".format(name, param_size))
 
-        if np.size(value) != param_size:
-            raise InputParameterError(
-                "Input value for parameter {0!r} does not have {1} elements "
-                "as the current value does".format(self._name, param_size))
-
-        model._parameters[param_slice] = np.array(value).ravel()
+            model._parameters[param_slice] = np.array(value).ravel()
+        _update_parameter_value(model, self._name, value)
+        if hasattr(model, "_param_map"):
+            submodel_ind, param_name = model._param_map[self._name]
+            if hasattr(model._submodels[submodel_ind], "_param_metrics"):
+                _update_parameter_value(model._submodels[submodel_ind], param_name, value)
 
     @staticmethod
     def _create_value_wrapper(wrapper, model):
@@ -730,7 +871,12 @@ class Parameter(OrderedDescriptor):
 
     def __array__(self, dtype=None):
         # Make np.asarray(self) work a little more straightforwardly
-        return np.asarray(self.value, dtype=dtype)
+        arr = np.asarray(self.value, dtype=dtype)
+
+        if self.unit is not None:
+            arr = Quantity(arr, self.unit, copy=False)
+
+        return arr
 
     def __nonzero__(self):
         if self._model is None:
@@ -760,3 +906,15 @@ class Parameter(OrderedDescriptor):
     __ge__ = _binary_comparison_operation(operator.ge)
     __neg__ = _unary_arithmetic_operation(operator.neg)
     __abs__ = _unary_arithmetic_operation(operator.abs)
+
+
+def param_repr_oneline(param):
+    """
+    Like array_repr_oneline but works on `Parameter` objects and supports
+    rendering parameters with units like quantities.
+    """
+
+    out = array_repr_oneline(param.value)
+    if param.unit is not None:
+        out = '{0} {1!s}'.format(out, param.unit)
+    return out
