@@ -6,7 +6,7 @@ Implements projections--particularly sky projections defined in WCS Paper II
 [1]_.
 
 All angles are set and and displayed in degrees but internally computations are
-performed in radians.
+performed in radians. All functions expect inputs and outputs degrees.
 
 References
 ----------
@@ -23,9 +23,10 @@ import numpy as np
 from .core import Model
 from .parameters import Parameter, InputParameterError
 
-from ..utils import deprecated
+from .. import units as u
 
 from . import _projections
+from .utils import _to_radian, _to_orig_unit
 
 
 projcodes = [
@@ -103,8 +104,9 @@ __all__ = ['Projection', 'Pix2SkyProjection', 'Sky2PixProjection',
 class Projection(Model):
     """Base class for all sky projections."""
 
-    # the radius of the projection sphere, by which x,y are scaled
-    r0 = 180 / np.pi
+    # Radius of the generating sphere.
+    # This sets the circumference to 360 deg so that arc length is measured in deg.
+    r0 = 180 * u.deg / np.pi
 
     @abc.abstractproperty
     def inverse(self):
@@ -119,6 +121,17 @@ class Pix2SkyProjection(Projection):
     inputs = ('x', 'y')
     outputs = ('phi', 'theta')
 
+    input_units_strict = True
+    input_units_allow_dimensionless = True
+
+    @property
+    def input_units(self):
+        return {'x': u.deg, 'y': u.deg}
+
+    @property
+    def return_units(self):
+        return {'phi': u.deg, 'theta': u.deg}
+
 
 class Sky2PixProjection(Projection):
     """Base class for all Sky2Pix projections."""
@@ -126,6 +139,17 @@ class Sky2PixProjection(Projection):
     inputs = ('phi', 'theta')
     outputs = ('x', 'y')
 
+    input_units_strict = True
+    input_units_allow_dimensionless = True
+
+    @property
+    def input_units(self):
+        return {'phi': u.deg, 'theta': u.deg}
+
+    @property
+    def return_units(self):
+        return {'x': u.deg, 'y': u.deg}
+
 
 class Zenithal(Projection):
     r"""Base class for all Zenithal projections.
@@ -177,7 +201,7 @@ class Pix2Sky_ZenithalPerspective(Pix2SkyProjection, Zenithal):
     """
 
     mu = Parameter(default=0.0)
-    gamma = Parameter(default=0.0, getter=np.rad2deg, setter=np.deg2rad)
+    gamma = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
 
     def __init__(self, mu=mu.default, gamma=gamma.default, **kwargs):
         # units : mu - in spherical radii, gamma - in deg
@@ -196,15 +220,7 @@ class Pix2Sky_ZenithalPerspective(Pix2SkyProjection, Zenithal):
 
     @classmethod
     def evaluate(cls, x, y, mu, gamma):
-        return _projections.azpx2s(x, y, mu, np.rad2deg(gamma))
-
-    @deprecated('1.1', message='this method was never intended as part of '
-                               'the public API and will be removed; if you '
-                               'do need its functionality use '
-                               'model.mu.validator(val)')
-    def check_mu(self, value):
-        return self.mu.validator(value)
-
+        return _projections.azpx2s(x, y, mu, _to_orig_unit(gamma))
 
 
 Pix2Sky_AZP = Pix2Sky_ZenithalPerspective
@@ -236,7 +252,7 @@ class Sky2Pix_ZenithalPerspective(Sky2PixProjection, Zenithal):
     """
 
     mu = Parameter(default=0.0)
-    gamma = Parameter(default=0.0, getter=np.rad2deg, setter=np.deg2rad)
+    gamma = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
 
     @mu.validator
     def mu(self, value):
@@ -251,7 +267,7 @@ class Sky2Pix_ZenithalPerspective(Sky2PixProjection, Zenithal):
     @classmethod
     def evaluate(cls, phi, theta, mu, gamma):
         return _projections.azps2x(
-            phi, theta, mu, np.rad2deg(gamma))
+            phi, theta, mu, _to_orig_unit(gamma))
 
 
 Sky2Pix_AZP = Sky2Pix_ZenithalPerspective
@@ -285,8 +301,8 @@ class Pix2Sky_SlantZenithalPerspective(Pix2SkyProjection, Zenithal):
         return mu
 
     mu = Parameter(default=0.0, setter=_validate_mu)
-    phi0 = Parameter(default=0.0, getter=np.rad2deg, setter=np.deg2rad)
-    theta0 = Parameter(default=90.0, getter=np.rad2deg, setter=np.deg2rad)
+    phi0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
+    theta0 = Parameter(default=90.0, getter=_to_orig_unit, setter=_to_radian)
 
     @property
     def inverse(self):
@@ -296,14 +312,7 @@ class Pix2Sky_SlantZenithalPerspective(Pix2SkyProjection, Zenithal):
     @classmethod
     def evaluate(cls, x, y, mu, phi0, theta0):
         return _projections.szpx2s(
-            x, y, mu, np.rad2deg(phi0), np.rad2deg(theta0))
-
-    @deprecated('1.1', message='this method was never intended as part of '
-                               'the public API and will be removed; if you '
-                               'do need its functionality use '
-                               'model.mu.validator(val)')
-    def check_mu(self, value):
-        return self.mu.validator(value)
+            x, y, mu, _to_orig_unit(phi0), _to_orig_unit(theta0))
 
 
 Pix2Sky_SZP = Pix2Sky_SlantZenithalPerspective
@@ -336,8 +345,8 @@ class Sky2Pix_SlantZenithalPerspective(Sky2PixProjection, Zenithal):
         return mu
 
     mu = Parameter(default=0.0, setter=_validate_mu)
-    phi0 = Parameter(default=0.0, getter=np.rad2deg, setter=np.deg2rad)
-    theta0 = Parameter(default=0.0, getter=np.rad2deg, setter=np.deg2rad)
+    phi0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
+    theta0 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
 
     @property
     def inverse(self):
@@ -347,7 +356,7 @@ class Sky2Pix_SlantZenithalPerspective(Sky2PixProjection, Zenithal):
     @classmethod
     def evaluate(cls, phi, theta, mu, phi0, theta0):
         return _projections.szps2x(
-            phi, theta, mu, np.rad2deg(phi0), np.rad2deg(theta0))
+            phi, theta, mu, _to_orig_unit(phi0), _to_orig_unit(theta0))
 
 
 Sky2Pix_SZP = Sky2Pix_SlantZenithalPerspective
@@ -873,8 +882,8 @@ class Pix2Sky_PlateCarree(Pix2SkyProjection, Cylindrical):
     @staticmethod
     def evaluate(x, y):
         # The intermediate variables are only used here for clarity
-        phi = x.copy()
-        theta = y.copy()
+        phi = np.array(x, copy=True)
+        theta = np.array(y, copy=True)
 
         return phi, theta
 
@@ -900,8 +909,8 @@ class Sky2Pix_PlateCarree(Sky2PixProjection, Cylindrical):
     @staticmethod
     def evaluate(phi, theta):
         # The intermediate variables are only used here for clarity
-        x = phi.copy()
-        y = theta.copy()
+        x = np.array(phi, copy=True)
+        y = np.array(theta, copy=True)
 
         return x, y
 
@@ -928,6 +937,7 @@ class Pix2Sky_Mercator(Pix2SkyProjection, Cylindrical):
     def evaluate(cls, x, y):
         return _projections.merx2s(x, y)
 
+
 Pix2Sky_MER = Pix2Sky_Mercator
 
 
@@ -983,6 +993,7 @@ class Pix2Sky_SansonFlamsteed(Pix2SkyProjection, PseudoCylindrical):
     def evaluate(cls, x, y):
         return _projections.sflx2s(x, y)
 
+
 Pix2Sky_SFL = Pix2Sky_SansonFlamsteed
 
 
@@ -1028,6 +1039,7 @@ class Pix2Sky_Parabolic(Pix2SkyProjection, PseudoCylindrical):
     def evaluate(cls, x, y):
         return _projections.parx2s(x, y)
 
+
 Pix2Sky_PAR = Pix2Sky_Parabolic
 
 
@@ -1073,6 +1085,7 @@ class Pix2Sky_Molleweide(Pix2SkyProjection, PseudoCylindrical):
     def evaluate(cls, x, y):
         return _projections.molx2s(x, y)
 
+
 Pix2Sky_MOL = Pix2Sky_Molleweide
 
 
@@ -1125,6 +1138,7 @@ class Pix2Sky_HammerAitoff(Pix2SkyProjection, PseudoCylindrical):
     def evaluate(cls, x, y):
         return _projections.aitx2s(x, y)
 
+
 Pix2Sky_AIT = Pix2Sky_HammerAitoff
 
 
@@ -1152,6 +1166,7 @@ class Sky2Pix_HammerAitoff(Sky2PixProjection, PseudoCylindrical):
     def evaluate(cls, phi, theta):
         return _projections.aits2x(phi, theta)
 
+
 Sky2Pix_AIT = Sky2Pix_HammerAitoff
 
 
@@ -1179,8 +1194,8 @@ class Conic(Projection):
     .. math::
         C = \frac{180^\circ \cos \theta}{\pi R_\theta}
     """
-    sigma = Parameter(default=90.0, getter=np.rad2deg, setter=np.deg2rad)
-    delta = Parameter(default=0.0, getter=np.rad2deg, setter=np.deg2rad)
+    sigma = Parameter(default=90.0, getter=_to_orig_unit, setter=_to_radian)
+    delta = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
 
 
 class Pix2Sky_ConicPerspective(Pix2SkyProjection, Conic):
@@ -1216,7 +1231,8 @@ class Pix2Sky_ConicPerspective(Pix2SkyProjection, Conic):
 
     @classmethod
     def evaluate(cls, x, y, sigma, delta):
-        return _projections.copx2s(x, y, np.rad2deg(sigma), np.rad2deg(delta))
+        return _projections.copx2s(x, y, _to_orig_unit(sigma), _to_orig_unit(delta))
+
 
 Pix2Sky_COP = Pix2Sky_ConicPerspective
 
@@ -1255,7 +1271,8 @@ class Sky2Pix_ConicPerspective(Sky2PixProjection, Conic):
     @classmethod
     def evaluate(cls, phi, theta, sigma, delta):
         return _projections.cops2x(phi, theta,
-                                   np.rad2deg(sigma), np.rad2deg(delta))
+                                   _to_orig_unit(sigma), _to_orig_unit(delta))
+
 
 Sky2Pix_COP = Sky2Pix_ConicPerspective
 
@@ -1298,7 +1315,8 @@ class Pix2Sky_ConicEqualArea(Pix2SkyProjection, Conic):
 
     @classmethod
     def evaluate(cls, x, y, sigma, delta):
-        return _projections.coex2s(x, y, np.rad2deg(sigma), np.rad2deg(delta))
+        return _projections.coex2s(x, y, _to_orig_unit(sigma), _to_orig_unit(delta))
+
 
 Pix2Sky_COE = Pix2Sky_ConicEqualArea
 
@@ -1342,7 +1360,8 @@ class Sky2Pix_ConicEqualArea(Sky2PixProjection, Conic):
     @classmethod
     def evaluate(cls, phi, theta, sigma, delta):
         return _projections.coes2x(phi, theta,
-                                   np.rad2deg(sigma), np.rad2deg(delta))
+                                   _to_orig_unit(sigma), _to_orig_unit(delta))
+
 
 Sky2Pix_COE = Sky2Pix_ConicEqualArea
 
@@ -1381,7 +1400,8 @@ class Pix2Sky_ConicEquidistant(Pix2SkyProjection, Conic):
 
     @classmethod
     def evaluate(cls, x, y, sigma, delta):
-        return _projections.codx2s(x, y, np.rad2deg(sigma), np.rad2deg(delta))
+        return _projections.codx2s(x, y, _to_orig_unit(sigma), _to_orig_unit(delta))
+
 
 Pix2Sky_COD = Pix2Sky_ConicEquidistant
 
@@ -1421,7 +1441,8 @@ class Sky2Pix_ConicEquidistant(Sky2PixProjection, Conic):
     @classmethod
     def evaluate(cls, phi, theta, sigma, delta):
         return _projections.cods2x(phi, theta,
-                                   np.rad2deg(sigma), np.rad2deg(delta))
+                                   _to_orig_unit(sigma), _to_orig_unit(delta))
+
 
 Sky2Pix_COD = Sky2Pix_ConicEquidistant
 
@@ -1469,7 +1490,8 @@ class Pix2Sky_ConicOrthomorphic(Pix2SkyProjection, Conic):
 
     @classmethod
     def evaluate(cls, x, y, sigma, delta):
-        return _projections.coox2s(x, y, np.rad2deg(sigma), np.rad2deg(delta))
+        return _projections.coox2s(x, y, _to_orig_unit(sigma), _to_orig_unit(delta))
+
 
 Pix2Sky_COO = Pix2Sky_ConicOrthomorphic
 
@@ -1518,7 +1540,8 @@ class Sky2Pix_ConicOrthomorphic(Sky2PixProjection, Conic):
     @classmethod
     def evaluate(cls, phi, theta, sigma, delta):
         return _projections.coos2x(phi, theta,
-                                   np.rad2deg(sigma), np.rad2deg(delta))
+                                   _to_orig_unit(sigma), _to_orig_unit(delta))
+
 
 Sky2Pix_COO = Sky2Pix_ConicOrthomorphic
 
@@ -1553,7 +1576,7 @@ class Pix2Sky_BonneEqualArea(Pix2SkyProjection, PseudoConic):
     theta1 : float
         Bonne conformal latitude, in degrees.
     """
-    theta1 = Parameter(default=0.0, getter=np.rad2deg, setter=np.deg2rad)
+    theta1 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
 
     @property
     def inverse(self):
@@ -1561,7 +1584,8 @@ class Pix2Sky_BonneEqualArea(Pix2SkyProjection, PseudoConic):
 
     @classmethod
     def evaluate(cls, x, y, theta1):
-        return _projections.bonx2s(x, y, np.rad2deg(theta1))
+        return _projections.bonx2s(x, y, _to_orig_unit(theta1))
+
 
 Pix2Sky_BON = Pix2Sky_BonneEqualArea
 
@@ -1588,7 +1612,7 @@ class Sky2Pix_BonneEqualArea(Sky2PixProjection, PseudoConic):
     theta1 : float
         Bonne conformal latitude, in degrees.
     """
-    theta1 = Parameter(default=0.0, getter=np.rad2deg, setter=np.deg2rad)
+    theta1 = Parameter(default=0.0, getter=_to_orig_unit, setter=_to_radian)
 
     @property
     def inverse(self):
@@ -1597,7 +1621,8 @@ class Sky2Pix_BonneEqualArea(Sky2PixProjection, PseudoConic):
     @classmethod
     def evaluate(cls, phi, theta, theta1):
         return _projections.bons2x(phi, theta,
-                                   np.rad2deg(theta1))
+                                   _to_orig_unit(theta1))
+
 
 Sky2Pix_BON = Sky2Pix_BonneEqualArea
 
@@ -1616,6 +1641,7 @@ class Pix2Sky_Polyconic(Pix2SkyProjection, PseudoConic):
     def evaluate(cls, x, y):
         return _projections.pcox2s(x, y)
 
+
 Pix2Sky_PCO = Pix2Sky_Polyconic
 
 
@@ -1633,6 +1659,7 @@ class Sky2Pix_Polyconic(Sky2PixProjection, PseudoConic):
     def evaluate(cls, phi, theta):
         return _projections.pcos2x(phi, theta)
 
+
 Sky2Pix_PCO = Sky2Pix_Polyconic
 
 
@@ -1667,6 +1694,7 @@ class Pix2Sky_TangentialSphericalCube(Pix2SkyProjection, QuadCube):
     def evaluate(cls, x, y):
         return _projections.tscx2s(x, y)
 
+
 Pix2Sky_TSC = Pix2Sky_TangentialSphericalCube
 
 
@@ -1684,6 +1712,7 @@ class Sky2Pix_TangentialSphericalCube(Sky2PixProjection, QuadCube):
     def evaluate(cls, phi, theta):
         return _projections.tscs2x(phi, theta)
 
+
 Sky2Pix_TSC = Sky2Pix_TangentialSphericalCube
 
 
@@ -1701,6 +1730,7 @@ class Pix2Sky_COBEQuadSphericalCube(Pix2SkyProjection, QuadCube):
     def evaluate(cls, x, y):
         return _projections.cscx2s(x, y)
 
+
 Pix2Sky_CSC = Pix2Sky_COBEQuadSphericalCube
 
 
@@ -1718,6 +1748,7 @@ class Sky2Pix_COBEQuadSphericalCube(Sky2PixProjection, QuadCube):
     def evaluate(cls, phi, theta):
         return _projections.cscs2x(phi, theta)
 
+
 Sky2Pix_CSC = Sky2Pix_COBEQuadSphericalCube
 
 
@@ -1735,6 +1766,7 @@ class Pix2Sky_QuadSphericalCube(Pix2SkyProjection, QuadCube):
     def evaluate(cls, x, y):
         return _projections.qscx2s(x, y)
 
+
 Pix2Sky_QSC = Pix2Sky_QuadSphericalCube
 
 
@@ -1752,6 +1784,7 @@ class Sky2Pix_QuadSphericalCube(Sky2PixProjection, QuadCube):
     def evaluate(cls, phi, theta):
         return _projections.qscs2x(phi, theta)
 
+
 Sky2Pix_QSC = Sky2Pix_QuadSphericalCube
 
 
@@ -1785,6 +1818,7 @@ class Pix2Sky_HEALPix(Pix2SkyProjection, HEALPix):
     def evaluate(cls, x, y, H, X):
         return _projections.hpxx2s(x, y, H, X)
 
+
 Pix2Sky_HPX = Pix2Sky_HEALPix
 
 
@@ -1813,6 +1847,7 @@ class Sky2Pix_HEALPix(Sky2PixProjection, HEALPix):
     def evaluate(cls, phi, theta, H, X):
         return _projections.hpxs2x(phi, theta, H, X)
 
+
 Sky2Pix_HPX = Sky2Pix_HEALPix
 
 
@@ -1830,6 +1865,7 @@ class Pix2Sky_HEALPixPolar(Pix2SkyProjection, HEALPix):
     def evaluate(cls, x, y):
         return _projections.xphx2s(x, y)
 
+
 Pix2Sky_XPH = Pix2Sky_HEALPixPolar
 
 
@@ -1847,6 +1883,7 @@ class Sky2Pix_HEALPixPolar(Sky2PixProjection, HEALPix):
     def evaluate(cls, phi, theta):
         return _projections.hpxs2x(phi, theta)
 
+
 Sky2Pix_XPH = Sky2Pix_HEALPixPolar
 
 
