@@ -60,11 +60,11 @@ from ..functional_models import (
     Ring2D, Sersic1D, Sersic2D, Voigt1D, Planar2D)
 from ..polynomial import Polynomial1D, Polynomial2D
 from ..powerlaws import (
-    PowerLaw1D, BrokenPowerLaw1D, ExponentialCutoffPowerLaw1D,
+    PowerLaw1D, BrokenPowerLaw1D, SmoothlyBrokenPowerLaw1D, ExponentialCutoffPowerLaw1D,
     LogParabola1D)
 import numpy as np
 
-#1D Models
+# 1D Models
 models_1D = {
     Gaussian1D: {
         'parameters': [1, 0, 1],
@@ -159,6 +159,15 @@ models_1D = {
         'log_fit': True
     },
 
+    SmoothlyBrokenPowerLaw1D: {
+        'parameters': [1, 1, -2, 2, 0.5],
+        'constraints': {'fixed': {'x_break': True, 'delta': True}},
+        'x_values': [0.01, 1, 100],
+        'y_values': [3.99920012e-04, 1.0, 3.99920012e-04],
+        'x_lim': [0.01, 100],
+        'log_fit': True
+    },
+
     ExponentialCutoffPowerLaw1D: {
         'parameters': [1, 1, 2, 3],
         'constraints': {'fixed': {'x_0': True}},
@@ -192,7 +201,7 @@ models_1D = {
         'y_values': [2.78629391e+02, 5.69791430e+01, 3.38788244e+00,
                      2.23941982e-02],
         'requires_scipy': True,
-        'x_lim': [0,10],
+        'x_lim': [0, 10],
         'log_fit': True
     },
 
