@@ -371,7 +371,7 @@ class TestParameterInitialization(object):
         t = TParModel(10, [1, 2])
         assert len(t) == 1
         assert t.model_set_axis is False
-        assert np.issubdtype(t.param_sets.dtype, object)
+        assert np.issubdtype(t.param_sets.dtype, np.object_)
         assert len(t.param_sets) == 2
         assert np.all(t.param_sets[0] == [10])
         assert np.all(t.param_sets[1] == [[1, 2]])
@@ -439,7 +439,7 @@ class TestParameterInitialization(object):
         assert len(t) == 1
         assert t.model_set_axis is False
         assert len(t.param_sets) == 2
-        assert np.issubdtype(t.param_sets.dtype, object)
+        assert np.issubdtype(t.param_sets.dtype, np.object_)
         assert np.all(t.param_sets[0] == [[[10, 20, 30], [40, 50, 60]]])
         assert np.all(t.param_sets[1] == [[1, 2, 3]])
         assert np.all(t.parameters == [10, 20, 30, 40, 50, 60, 1, 2, 3])
@@ -471,7 +471,7 @@ class TestParameterInitialization(object):
         assert len(t) == 2
         assert t.model_set_axis == 0
         assert len(t.param_sets) == 2
-        assert np.issubdtype(t.param_sets.dtype, object)
+        assert np.issubdtype(t.param_sets.dtype, np.object_)
         assert np.all(t.param_sets[0] == [[10], [20]])
         assert np.all(t.param_sets[1] == [[1, 2], [3, 4]])
         assert np.all(t.parameters == [10, 20, 1, 2, 3, 4])
@@ -510,7 +510,7 @@ class TestParameterInitialization(object):
         assert len(t) == 2
         assert t.model_set_axis == 0
         assert len(t.param_sets) == 2
-        assert np.issubdtype(t.param_sets.dtype, object)
+        assert np.issubdtype(t.param_sets.dtype, np.object_)
         assert np.all(t.param_sets[0] == [[[10, 20], [30, 40]],
                                           [[50, 60], [70, 80]]])
         assert np.all(t.param_sets[1] == [[[1, 2]], [[3, 4]]])
@@ -544,7 +544,7 @@ class TestParameterInitialization(object):
         assert len(t) == 2
         assert t.model_set_axis == -1
         assert len(t.param_sets) == 2
-        assert np.issubdtype(t.param_sets.dtype, object)
+        assert np.issubdtype(t.param_sets.dtype, np.object_)
         assert np.all(t.param_sets[0] == [[[10, 50], [20, 60]],
                                           [[30, 70], [40, 80]]])
         assert np.all(t.param_sets[1] == [[[1, 3], [2, 4]]])
@@ -584,7 +584,7 @@ class TestParameterInitialization(object):
         assert len(t4) == 1
         assert t4.coeff.shape == (2, 2)
         assert t4.e.shape == (2,)
-        assert np.issubdtype(t4.param_sets.dtype, object)
+        assert np.issubdtype(t4.param_sets.dtype, np.object_)
         assert np.all(t4.param_sets[0] == [[1, 2], [3, 4]])
         assert np.all(t4.param_sets[1] == [5, 6])
 
