@@ -5,16 +5,20 @@
 from __future__ import (absolute_import, unicode_literals, division,
                         print_function)
 import os
+
+import pytest
 import numpy as np
 from numpy.testing import utils
+
 from .. import projections
 from ..parameters import InputParameterError
 
+from ... import units as u
 from ...io import fits
 from ... import wcs
 from ...utils.data import get_pkg_data_filename
-from ...tests.helper import pytest
 from ...extern.six.moves import range, zip
+from ...tests.helper import assert_quantity_allclose
 
 
 def test_Projection_properties():
@@ -89,6 +93,69 @@ def test_Pix2Sky(code):
     utils.assert_almost_equal(np.asarray(theta), wcs_theta)
 
 
+@pytest.mark.parametrize(('code',), pars)
+def test_Sky2Pix_unit(code):
+    """Check astropy model eval against wcslib eval"""
+
+    wcs_map = os.path.join(os.pardir, os.pardir, "wcs", "tests", "maps",
+                           "1904-66_{0}.hdr".format(code))
+    test_file = get_pkg_data_filename(wcs_map)
+    header = fits.Header.fromfile(test_file, endcard=False, padding=False)
+
+    params = []
+    for i in range(3):
+        key = 'PV2_{0}'.format(i + 1)
+        if key in header:
+            params.append(header[key])
+
+    w = wcs.WCS(header)
+    w.wcs.crval = [0., 0.]
+    w.wcs.crpix = [0, 0]
+    w.wcs.cdelt = [1, 1]
+    wcslibout = w.wcs.p2s([PIX_COORDINATES], 1)
+    wcs_pix = w.wcs.s2p(wcslibout['world'], 1)['pixcrd']
+    model = getattr(projections, 'Sky2Pix_' + code)
+    tinv = model(*params)
+    x, y = tinv(wcslibout['phi'] * u.deg, wcslibout['theta'] * u.deg)
+    assert_quantity_allclose(x, wcs_pix[:, 0] * u.deg)
+    assert_quantity_allclose(y, wcs_pix[:, 1] * u.deg)
+
+
+@pytest.mark.parametrize(('code',), pars)
+def test_Pix2Sky_unit(code):
+    """Check astropy model eval against wcslib eval"""
+
+    wcs_map = os.path.join(os.pardir, os.pardir, "wcs", "tests", "maps",
+                           "1904-66_{0}.hdr".format(code))
+    test_file = get_pkg_data_filename(wcs_map)
+    header = fits.Header.fromfile(test_file, endcard=False, padding=False)
+
+    params = []
+    for i in range(3):
+        key = 'PV2_{0}'.format(i + 1)
+        if key in header:
+            params.append(header[key])
+
+    w = wcs.WCS(header)
+    w.wcs.crval = [0., 0.]
+    w.wcs.crpix = [0, 0]
+    w.wcs.cdelt = [1, 1]
+    wcslibout = w.wcs.p2s([PIX_COORDINATES], 1)
+    wcs_phi = wcslibout['phi']
+    wcs_theta = wcslibout['theta']
+    model = getattr(projections, 'Pix2Sky_' + code)
+    tanprj = model(*params)
+    phi, theta = tanprj(*PIX_COORDINATES * u.deg)
+    assert_quantity_allclose(phi, wcs_phi * u.deg)
+    assert_quantity_allclose(theta, wcs_theta * u.deg)
+    phi, theta = tanprj(*(PIX_COORDINATES * u.deg).to(u.rad))
+    assert_quantity_allclose(phi, wcs_phi * u.deg)
+    assert_quantity_allclose(theta, wcs_theta * u.deg)
+    phi, theta = tanprj(*(PIX_COORDINATES * u.deg).to(u.arcmin))
+    assert_quantity_allclose(phi, wcs_phi * u.deg)
+    assert_quantity_allclose(theta, wcs_theta * u.deg)
+
+
 @pytest.mark.parametrize(('code',), pars)
 def test_projection_default(code):
     """Check astropy model eval with default parameters"""
@@ -234,10 +301,10 @@ def test_c_projections_shaped():
 
     utils.assert_allclose(
         phi,
-        [[0., 90., 90., 90., 90.,],
+        [[0., 90., 90., 90., 90.],
          [180., 165.96375653, 153.43494882, 143.13010235, 135.]])
 
     utils.assert_allclose(
         theta,
         [[90., 89.75000159, 89.50001269, 89.25004283, 89.00010152],
-         [89.00010152, 88.96933478, 88.88210788, 88.75019826,  88.58607353]])
+         [89.00010152, 88.96933478, 88.88210788, 88.75019826, 88.58607353]])
