@@ -15,6 +15,7 @@ from ..extern import six
 from ..extern.six.moves import range, zip
 
 from ..utils import isiterable, check_broadcast
+from ..utils.compat import NUMPY_LT_1_14
 from ..utils.compat.funcsigs import signature
 
 from .. import units as u
@@ -493,8 +494,8 @@ def array_repr_oneline(array):
     """
     Represents a multi-dimensional Numpy array flattened onto a single line.
     """
-
-    r = np.array2string(array, separator=',', suppress_small=True)
+    sep = ',' if NUMPY_LT_1_14 else ', '
+    r = np.array2string(array, separator=sep, suppress_small=True)
     return ' '.join(l.strip() for l in r.splitlines())
 
 
