@@ -1,13 +1,11 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-from ...nddata import NDData
-from ...mixins.ndio import NDIOMixin
+from ... import NDData, NDIOMixin, NDDataRef
 
 
-# Define minimal class that uses the I/O mixin
-class NDDataIO(NDIOMixin, NDData):
-    pass
+# Alias NDDataAllMixins in case this will be renamed ... :-)
+NDDataIO = NDDataRef
 
 
 def test_simple_write_read(tmpdir):
