@@ -4,9 +4,9 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
+import pytest
 import numpy as np
 
-from ...tests.helper import pytest
 from ..nddata import NDData
 from ..compat import NDDataArray
 from ..nduncertainty import StdDevUncertainty
