@@ -718,9 +718,12 @@ class BaseColumn(_ColumnGetitemShim, np.ndarray):
         elif isinstance(value, bytes) or value is np.ma.masked:
             pass
         else:
-            value = np.asarray(value)
-            if value.dtype.char == 'U':
-                value = np.char.encode(value, encoding='utf-8')
+            arr = np.asarray(value)
+            if arr.dtype.char == 'U':
+                arr = np.char.encode(arr, encoding='utf-8')
+                if isinstance(value, np.ma.MaskedArray):
+                    arr = np.ma.array(arr, mask=value.mask, copy=False)
+            value = arr
 
         return value
 
@@ -769,7 +772,7 @@ class Column(BaseColumn):
 
       The ``dtype`` argument can be any value which is an acceptable
       fixed-size data-type initializer for the numpy.dtype() method.  See
-      `<http://docs.scipy.org/doc/numpy/reference/arrays.dtypes.html>`_.
+      `<https://docs.scipy.org/doc/numpy/reference/arrays.dtypes.html>`_.
       Examples include:
 
       - Python non-string type (float, int, bool)
@@ -922,11 +925,34 @@ class Column(BaseColumn):
         Make comparison methods which encode the ``other`` object to utf-8
         in the case of a bytestring dtype for Py3+.
         """
+        swapped_oper = {'__eq__': '__eq__',
+                        '__ne__': '__ne__',
+                        '__gt__': '__lt__',
+                        '__lt__': '__gt__',
+                        '__ge__': '__le__',
+                        '__le__': '__ge__'}[oper]
 
         def _compare(self, other):
+            op = oper  # copy enclosed ref to allow swap below
+
+            # Special case to work around #6838.  Other combinations work OK,
+            # see tests.test_column.test_unicode_sandwich_compare().  In this
+            # case just swap self and other.
+            #
+            # This is related to an issue in numpy that was addressed in np 1.13.
+            # However that fix does not make this problem go away, but maybe
+            # future numpy versions will do so.  NUMPY_LT_1_13 to get the
+            # attention of future maintainers to check (by deleting or versioning
+            # the if block below).  See #6899 discussion.
+            if (isinstance(self, MaskedColumn) and self.dtype.kind == 'U' and
+                    isinstance(other, MaskedColumn) and other.dtype.kind == 'S'):
+                self, other = other, self
+                op = swapped_oper
+
             if not six.PY2 and self.dtype.char == 'S':
                 other = self._encode_str(other)
-            return getattr(self.data, oper)(other)
+            return getattr(self.data, op)(other)
+
         return _compare
 
     __eq__ = _make_compare('__eq__')
@@ -1038,7 +1064,7 @@ class MaskedColumn(Column, _MaskedColumnGetitemShim, ma.MaskedArray):
 
       The ``dtype`` argument can be any value which is an acceptable
       fixed-size data-type initializer for the numpy.dtype() method.  See
-      `<http://docs.scipy.org/doc/numpy/reference/arrays.dtypes.html>`_.
+      `<https://docs.scipy.org/doc/numpy/reference/arrays.dtypes.html>`_.
       Examples include:
 
       - Python non-string type (float, int, bool)
