@@ -25,12 +25,8 @@ def default_format_func(format_, val):
         return text_type(val)
 
 
-_format_funcs = {}
-
-
 # The first three functions are helpers for _auto_format_func
 
-
 def _use_str_for_masked_values(format_func):
     """Wrap format function to trap masked values.
 
@@ -53,7 +49,7 @@ def _possible_string_format_functions(format_):
 
 
 def get_auto_format_func(
-        col_name=None,
+        col=None,
         possible_string_format_functions=_possible_string_format_functions):
     """
     Return a wrapped ``auto_format_func`` function which is used in
@@ -86,9 +82,8 @@ def get_auto_format_func(
         if format_ is None:
             return default_format_func(format_, val)
 
-        format_key = (format_, col_name)
-        if format_key in _format_funcs:
-            return _format_funcs[format_key](format_, val)
+        if format_ in col.info._format_funcs:
+            return col.info._format_funcs[format_](format_, val)
 
         if six.callable(format_):
             format_func = lambda format_, val: format_(val)
@@ -140,7 +135,7 @@ def get_auto_format_func(
             # wrap them in a function that traps them.
             format_func = _use_str_for_masked_values(format_func)
 
-        _format_funcs[format_key] = format_func
+        col.info._format_funcs[format_] = format_func
         return out
 
     return _auto_format_func
@@ -422,9 +417,8 @@ class TableFormatter(object):
         col_format = col.info.format or getattr(col.info, 'default_format', None)
         pssf = (getattr(col.info, 'possible_string_format_functions', None) or
                 _possible_string_format_functions)
-        auto_format_func = get_auto_format_func(id(col), pssf)
-        format_key = (col_format, id(col))
-        format_func = _format_funcs.get(format_key, auto_format_func)
+        auto_format_func = get_auto_format_func(col, pssf)
+        format_func = col.info._format_funcs.get(col_format, auto_format_func)
 
         if len(col) > max_lines:
             if show_length is None:
