@@ -19,11 +19,11 @@ from copy import deepcopy
 from collections import OrderedDict
 import pickle
 
+import pytest
 import numpy as np
 
-from ...tests.helper import pytest
 from ... import table
-from ...table import table_helpers, Table
+from ...table import table_helpers, Table, QTable
 from ... import time
 from ... import units as u
 from ... import coordinates
@@ -72,6 +72,8 @@ class MyTable(table.Table):
 
 # Fixture to run all the Column tests for both an unmasked (ndarray)
 # and masked (MaskedArray) column.
+
+
 @pytest.fixture(params=['unmasked', 'masked', 'subclass'])
 def table_types(request):
     class TableTypes:
@@ -139,6 +141,9 @@ def table_type(request):
 # Stuff for testing mixin columns
 
 MIXIN_COLS = {'quantity': [0, 1, 2, 3] * u.m,
+              'longitude': coordinates.Longitude([0., 1., 5., 6.]*u.deg,
+                                                  wrap_angle=180.*u.deg),
+              'latitude': coordinates.Latitude([5., 6., 10., 11.]*u.deg),
               'time': time.Time([2000, 2001, 2002, 2003], format='jyear'),
               'skycoord': coordinates.SkyCoord(ra=[0, 1, 2, 3] * u.deg,
                                                dec=[0, 1, 2, 3] * u.deg),
@@ -146,6 +151,10 @@ MIXIN_COLS = {'quantity': [0, 1, 2, 3] * u.m,
               'ndarray': np.array([(7, 'a'), (8, 'b'), (9, 'c'), (9, 'c')],
                            dtype='<i4,|S1').view(table.NdarrayMixin),
               }
+MIXIN_COLS['earthlocation'] = coordinates.EarthLocation(
+    lon=MIXIN_COLS['longitude'], lat=MIXIN_COLS['latitude'],
+    height=MIXIN_COLS['quantity'])
+
 
 @pytest.fixture(params=sorted(MIXIN_COLS))
 def mixin_cols(request):
@@ -163,6 +172,7 @@ def mixin_cols(request):
 
     return cols
 
+
 @pytest.fixture(params=[False, True])
 def T1(request):
     T = Table.read([' a b c d',
@@ -181,3 +191,8 @@ def T1(request):
     if request.param:
         T.add_index('a')
     return T
+
+
+@pytest.fixture(params=[Table, QTable])
+def operation_table_type(request):
+    return request.param
