@@ -3,12 +3,13 @@
 
 # TEST_UNICODE_LITERALS
 
+import pytest
 import numpy as np
 
-from ...tests.helper import pytest
 from ... import table
-from ...table import Table
+from ...table import Table, QTable
 from ...table.table_helpers import simple_table
+from ... import units as u
 from ...extern.six import PY2
 from ...utils import console
 
@@ -110,6 +111,7 @@ def test_html_escaping():
         '<tr><td>3</td></tr>',
         '</table>']
 
+
 @pytest.mark.usefixtures('table_type')
 class TestPprint():
 
@@ -237,7 +239,6 @@ class TestPprint():
                          '   15    16    17',
                          'Length = 6 rows']
 
-
     def test_clip3(self, table_type):
         """Max lines below hard limit of 8 and max width below hard limit
         of 10
@@ -261,7 +262,6 @@ class TestPprint():
             assert len(lines) == max(8, min(102, max_lines))
 
 
-
 @pytest.mark.usefixtures('table_type')
 class TestFormat():
 
@@ -462,6 +462,7 @@ class TestFormatWithMaskedElements():
         t = Table([[1., 2., 3.], [3, 4, 5]], names=('a', 'b'), masked=True)
         t['a'].mask = [True, False, True]
         # mathematical function
+
         def format_func(x):
             if x is np.ma.masked:
                 return '!!'
@@ -534,10 +535,10 @@ def test_pprint_py3_bytes():
     Also make sure special characters are printed in Python 2.
     """
     val = str('val') if PY2 else bytes('val', encoding='utf-8')
-    blah = u'bläh'.encode('utf-8') if PY2 else bytes('bläh', encoding='utf-8')
+    blah = u'bläh'.encode('utf-8')
     dat = np.array([val, blah], dtype=[(str('col'), 'S10')])
     t = table.Table(dat)
-    assert t['col'].pformat() == ['col ', '----', ' val', u'bl\xe4h']
+    assert t['col'].pformat() == ['col ', '----', ' val', u'bläh']
 
 
 def test_pprint_nameless_col():
@@ -576,6 +577,7 @@ def test_html():
         u'<tr><td>2.0</td></tr>',
         u'</table>']
 
+
 def test_align():
     t = simple_table(2, kinds='iS')
     assert t.pformat() == [' a   b ',
@@ -639,7 +641,7 @@ def test_align():
                             '##1.00#       1',
                             '##2.00#       2']
 
-    assert t1.pformat(align='!<') ==  ['column1 column2',
+    assert t1.pformat(align='!<') == ['column1 column2',
                                        '------- -------',
                                        '1.00!!! 1!!!!!!',
                                        '2.00!!! 2!!!!!!']
@@ -673,3 +675,23 @@ def test_align():
 
     with pytest.raises(ValueError):
         t.pprint(align='x=')
+
+
+def test_auto_format_func():
+    """Test for #5802 (fix for #5800 where format_func key is not unique)"""
+    t = Table([[1, 2] * u.m])
+    t['col0'].format = '%f'
+    t.pformat()  # Force caching of format function
+
+    qt = QTable(t)
+    qt.pformat()  # Generates exception prior to #5802
+
+
+def test_decode_replace():
+    """
+    Test printing a bytestring column with a value that fails
+    decoding to utf-8 and gets replaced by U+FFFD.  See
+    https://docs.python.org/3/library/codecs.html#codecs.replace_errors
+    """
+    t = Table([[b'Z\xf0']])
+    assert t.pformat() == [u'col0', u'----', u'  Z\ufffd']
