@@ -8,12 +8,13 @@ import gc
 import sys
 from collections import OrderedDict
 
+import pytest
 import numpy as np
 from numpy.testing import assert_allclose
 
 from ...extern import six
 from ...io import fits
-from ...tests.helper import (pytest, assert_follows_unicode_guidelines,
+from ...tests.helper import (assert_follows_unicode_guidelines,
                              ignore_warnings, catch_warnings)
 from ...utils.data import get_pkg_data_filename
 from ... import table
