@@ -283,8 +283,8 @@ class Time(ShapedLikeNDArray):
             self._init_from_vals(val, val2, format, scale, copy,
                                  precision, in_subfmt, out_subfmt)
 
-        if self.location and (self.location.size > 1 and
-                              self.location.shape != self.shape):
+        if self.location is not None and (self.location.size > 1 and
+                                          self.location.shape != self.shape):
             try:
                 # check the location can be broadcast to self's shape.
                 self.location = broadcast_to(self.location, self.shape,
@@ -1213,7 +1213,7 @@ class Time(ShapedLikeNDArray):
             >>> t = Time(['1961-01-01', '2000-01-01'], scale='utc')
             >>> delta, status = t.get_delta_ut1_utc(return_status=True)
             >>> status == TIME_BEFORE_IERS_RANGE
-            array([ True, False], dtype=bool)
+            array([ True, False]...)
         """
         if iers_table is None:
             from ..utils.iers import IERS
