@@ -254,8 +254,9 @@ class TimeMJD(TimeFormat):
         # values in a vectorized operation.  But in most practical cases the
         # first one is probably biggest.
         self._check_scale(self._scale)  # Validate scale.
-        self.jd1, self.jd2 = day_frac(val1, val2)
-        self.jd1 += erfa.DJM0  # erfa.DJM0=2400000.5 (from erfam.h)
+        jd1, jd2 = day_frac(val1, val2)
+        jd1 += erfa.DJM0  # erfa.DJM0=2400000.5 (from erfam.h)
+        self.jd1, self.jd2 = day_frac(jd1, jd2)
 
     @property
     def value(self):
@@ -383,8 +384,7 @@ class TimeFromEpoch(TimeFormat):
                                   .format(self.name, self.epoch_scale,
                                           self.scale, err))
 
-        self.jd1 = tm._time.jd1
-        self.jd2 = tm._time.jd2
+        self.jd1, self.jd2 = day_frac(tm._time.jd1, tm._time.jd2)
 
     def to_value(self, parent=None):
         # Make sure that scale is the same as epoch scale so we can just
@@ -573,8 +573,9 @@ class TimeDatetime(TimeUnique):
             imin[...] = dt.minute
             dsec[...] = dt.second + dt.microsecond / 1e6
 
-        self.jd1, self.jd2 = erfa.dtf2d(self.scale.upper().encode('ascii'),
-                                        *iterator.operands[1:])
+        jd1, jd2 = erfa.dtf2d(self.scale.upper().encode('ascii'),
+                              *iterator.operands[1:])
+        self.jd1, self.jd2 = day_frac(jd1, jd2)
 
     def to_value(self, timezone=None, parent=None):
         """
@@ -747,8 +748,9 @@ class TimeString(TimeUnique):
             iy[...], im[...], id[...], ihr[...], imin[...], dsec[...] = (
                 self.parse_string(val.item(), subfmts))
 
-        self.jd1, self.jd2 = erfa.dtf2d(self.scale.upper().encode('ascii'),
-                                        *iterator.operands[1:])
+        jd1, jd2 = erfa.dtf2d(self.scale.upper().encode('ascii'),
+                              *iterator.operands[1:])
+        self.jd1, self.jd2 = day_frac(jd1, jd2)
 
     def str_kwargs(self):
         """
@@ -1076,7 +1078,8 @@ class TimeEpochDateString(TimeString):
 
         self._check_scale(self._scale)  # validate scale.
         epoch_to_jd = getattr(erfa, self.epoch_to_jd)
-        self.jd1, self.jd2 = epoch_to_jd(iterator.operands[-1])
+        jd1, jd2 = epoch_to_jd(iterator.operands[-1])
+        self.jd1, self.jd2 = day_frac(jd1, jd2)
 
     @property
     def value(self):
