@@ -18,7 +18,7 @@ class Latex(base.Base):
     Output LaTeX to display the unit based on IAU style guidelines.
 
     Attempts to follow the `IAU Style Manual
-    <http://www.iau.org/static/publications/stylemanual1989.pdf>`_.
+    <https://www.iau.org/static/publications/stylemanual1989.pdf>`_.
     """
 
     @classmethod
@@ -88,7 +88,7 @@ class Latex(base.Base):
         return r'$\mathrm{{{0}}}$'.format(s)
 
     @classmethod
-    def format_exponential_notation(cls, val):
+    def format_exponential_notation(cls, val, format_spec=".8g"):
         """
         Formats a value in exponential notation for LaTeX.
 
@@ -97,13 +97,16 @@ class Latex(base.Base):
         val : number
             The value to be formatted
 
+        format_spec : str, optional
+            Format used to split up mantissa and exponent
+
         Returns
         -------
         latex_string : str
             The value in exponential notation in a format suitable for LaTeX.
         """
         if np.isfinite(val):
-            m, ex = utils.split_mantissa_exponent(val)
+            m, ex = utils.split_mantissa_exponent(val, format_spec)
 
             parts = []
             if m:
@@ -129,9 +132,9 @@ class LatexInline(Latex):
     powers.
 
     Attempts to follow the `IAU Style Manual
-    <http://www.iau.org/static/publications/stylemanual1989.pdf>`_ and the
+    <https://www.iau.org/static/publications/stylemanual1989.pdf>`_ and the
     `ApJ and AJ style guide
-    <http://aas.org/authors/manuscript-preparation-aj-apj-author-instructions>`_.
+    <http://journals.aas.org/authors/manuscript.html>`_.
     """
     name = 'latex_inline'
 
