@@ -8,8 +8,7 @@ Handles the "Unicode" unit format.
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-from . import console
-from . import utils
+from . import console, utils
 
 
 class Unicode(console.Console):
@@ -20,22 +19,21 @@ class Unicode(console.Console):
     For example::
 
       >>> import astropy.units as u
-      >>> print(u.Ry.decompose().to_string('unicode'))  # doctest: +FLOAT_CMP
-                      m² kg
-      2.1798721×10⁻¹⁸ ─────
-                       s²
+      >>> print(u.bar.decompose().to_string('unicode'))
+              kg
+      100000 ────
+             m s²
     """
 
-    def __init__(self):
-        pass
-
     _times = "×"
     _line = "─"
 
-    def _get_unit_name(self, unit):
+    @classmethod
+    def _get_unit_name(cls, unit):
         return unit.get_format_name('unicode')
 
-    def _format_exponential_notation(self, val):
+    @classmethod
+    def format_exponential_notation(cls, val):
         m, ex = utils.split_mantissa_exponent(val)
 
         parts = []
@@ -44,12 +42,12 @@ class Unicode(console.Console):
 
         if ex:
             parts.append("10{0}".format(
-                self._format_superscript(ex)))
+                cls._format_superscript(ex)))
 
-        return self._times.join(parts)
+        return cls._times.join(parts)
 
-    @staticmethod
-    def _format_superscript(number):
+    @classmethod
+    def _format_superscript(cls, number):
         mapping = {
             '0': '⁰',
             '1': '¹',
