@@ -46,24 +46,24 @@ def get_grouped_by_powers(bases, powers):
     return positive, negative
 
 
-def split_mantissa_exponent(v):
+def split_mantissa_exponent(v, format_spec=".8g"):
     """
     Given a number, split it into its mantissa and base 10 exponent
     parts, each as strings.  If the exponent is too small, it may be
     returned as the empty string.
 
-    The precise rules are based on Python's "general purpose" (`g`)
-    formatting.
-
     Parameters
     ----------
     v : float
 
+    format_spec : str, optional
+        Number representation formatting string
+
     Returns
     -------
     mantissa, exponent : tuple of strings
     """
-    x = "{0:.8g}".format(v).split('e')
+    x = format(v, format_spec).split('e')
     if x[0] != '1.' + '0' * (len(x[0]) - 2):
         m = x[0]
     else:
