@@ -2,11 +2,20 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
 """
-This package defines colloquially used Imperial units.  By default, they
-are not enabled.  To enable them, do::
+This package defines colloquially used Imperial units.  They are
+available in the `astropy.units.imperial` namespace, but not in the
+top-level `astropy.units` namespace, e.g.::
 
-    >>> from astropy.units import imperial
-    >>> imperial.enable()  # doctest: +SKIP
+    >>> import astropy.units as u
+    >>> mph = u.imperial.mile / u.hour
+    >>> mph
+    Unit("mi / h")
+
+To include them in `~astropy.units.UnitBase.compose` and the results of
+`~astropy.units.UnitBase.find_equivalent_units`, do::
+
+    >>> import astropy.units as u
+    >>> u.imperial.enable()  # doctest: +SKIP
 """
 
 from __future__ import (absolute_import, division, print_function,
