@@ -23,7 +23,7 @@ from ..extern.six.moves import zip
 from .core import (Unit, dimensionless_unscaled, get_current_unit_registry,
                    UnitBase, UnitsError, UnitTypeError)
 from .format.latex import Latex
-from ..utils.compat import NUMPY_LT_1_13
+from ..utils.compat import NUMPY_LT_1_13, NUMPY_LT_1_14
 from ..utils.compat.misc import override__dir__
 from ..utils.compat.numpy import matmul
 from ..utils.misc import isiterable, InheritDocstrings
@@ -1247,7 +1247,8 @@ class Quantity(np.ndarray):
 
     def __repr__(self):
         prefixstr = '<' + self.__class__.__name__ + ' '
-        arrstr = np.array2string(self.view(np.ndarray), separator=',',
+        sep = ',' if NUMPY_LT_1_14 else ', '
+        arrstr = np.array2string(self.view(np.ndarray), separator=sep,
                                  prefix=prefixstr)
         return '{0}{1}{2:s}>'.format(prefixstr, arrstr, self._unitstr)
 
@@ -1272,8 +1273,10 @@ class Quantity(np.ndarray):
         pops = np.get_printoptions()
 
         format_spec = '.{}g'.format(pops['precision'])
+
         def float_formatter(value):
-            return Latex.format_exponential_notation(value, format_spec=format_spec)
+            return Latex.format_exponential_notation(value,
+                                                     format_spec=format_spec)
 
         try:
             formatter = {'float_kind': float_formatter}
@@ -1282,10 +1285,17 @@ class Quantity(np.ndarray):
                                     formatter=formatter)
 
             # the view is needed for the scalar case - value might be float
-            latex_value = np.array2string(
-                self.view(np.ndarray),
-                style=(float_formatter if self.dtype.kind == 'f' else repr),
-                max_line_width=np.inf, separator=',~')
+            if NUMPY_LT_1_14:   # style deprecated in 1.14
+                latex_value = np.array2string(
+                    self.view(np.ndarray),
+                    style=(float_formatter if self.dtype.kind == 'f'
+                           else repr),
+                    max_line_width=np.inf, separator=',~')
+            else:
+                latex_value = np.array2string(
+                    self.view(np.ndarray),
+                    max_line_width=np.inf, separator=',~')
+
             latex_value = latex_value.replace('...', r'\dots')
         finally:
             np.set_printoptions(**pops)
@@ -1393,10 +1403,16 @@ class Quantity(np.ndarray):
         try:
             _value = value.to_value(self.unit)
         except AttributeError:
+            # We're not a Quantity, so let's try a more general conversion.
+            # Plain arrays will be converted to dimensionless in the process,
+            # but anything with a unit attribute will use that.
             try:
-                _value = dimensionless_unscaled.to(self.unit, value)
+                _value = Quantity(value).to_value(self.unit)
             except UnitsError as exc:
-                if can_have_arbitrary_unit(value):
+                # last chance: if this was not something with a unit
+                # and is all 0, inf, or nan, we treat it as arbitrary unit.
+                if (not hasattr(value, 'unit') and
+                        can_have_arbitrary_unit(value)):
                     _value = value
                 else:
                     raise exc
