@@ -1,7 +1,8 @@
 import numpy as np
 
+import pytest
+
 from ... import units as u
-from ...tests.helper import pytest
 
 
 class TestQuantityLinAlgFuncs(object):
@@ -22,3 +23,17 @@ class TestQuantityLinAlgFuncs(object):
         q2 = np.array([4, 5, 6]) / u.s
         o = np.inner(q1, q2)
         assert o == 32 * u.m / u.s
+
+    @pytest.mark.xfail
+    def test_dot(self):
+        q1 = np.array([1., 2., 3.]) * u.m
+        q2 = np.array([4., 5., 6.]) / u.s
+        o = np.dot(q1, q2)
+        assert o == 32. * u.m / u.s
+
+    @pytest.mark.xfail
+    def test_matmul(self):
+        q1 = np.eye(3) * u.m
+        q2 = np.array([4., 5., 6.]) / u.s
+        o = np.matmul(q1, q2)
+        assert o == q2 / u.s
