@@ -4,6 +4,7 @@ This module contains helper functions and classes for handling metadata.
 """
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
+
 from ..extern import six
 from ..utils import wraps
 
@@ -15,6 +16,7 @@ from copy import deepcopy
 
 import numpy as np
 from ..utils.exceptions import AstropyWarning
+from ..utils.misc import dtype_bytes_or_chars
 
 
 __all__ = ['MergeConflictError', 'MergeConflictWarning', 'MERGE_STRATEGIES',
@@ -44,6 +46,11 @@ def common_dtype(arrs):
     ----------
     arrs : list of ndarray objects
         Arrays for which to find the common dtype
+
+    Returns
+    -------
+    dtype_str : str
+        String representation of dytpe (dtype ``str`` attribute)
     """
     def dtype(arr):
         return getattr(arr, 'dtype', np.dtype('O'))
@@ -65,7 +72,8 @@ def common_dtype(arrs):
     # values or the final arr_common = .. step is unpredictable.
     for i, arr in enumerate(arrs):
         if arr.dtype.kind in ('S', 'U'):
-            arrs[i] = [(u'0' if arr.dtype.kind == 'U' else b'0') * arr.itemsize]
+            arrs[i] = [(u'0' if arr.dtype.kind == 'U' else b'0') *
+                       dtype_bytes_or_chars(arr.dtype)]
 
     arr_common = np.array([arr[0] for arr in arrs])
     return arr_common.dtype.str
