@@ -5,15 +5,15 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from __future__ import absolute_import, division, print_function
 
+import pytest
 import numpy as np
 
 from ...extern import six
 from ..data_info import dtype_info_name
-from ...tests.helper import pytest
 
 STRING_TYPE_NAMES = {(False, 'S'): 'str',  # PY2
                      (False, 'U'): 'unicode',
-                     (True, 'S'): 'bytes', # not PY2
+                     (True, 'S'): 'bytes',  # not PY2
                      (True, 'U'): 'str'}
 
 DTYPE_TESTS = ((np.array(b'abcd').dtype, STRING_TYPE_NAMES[(not six.PY2, 'S')] + '4'),
@@ -30,6 +30,7 @@ DTYPE_TESTS = ((np.array(b'abcd').dtype, STRING_TYPE_NAMES[(not six.PY2, 'S')] +
                ('c16', 'complex128'),
                ('object', 'object'))
 
+
 @pytest.mark.parametrize('input,output', DTYPE_TESTS)
 def test_dtype_info_name(input, output):
     """
