@@ -119,7 +119,8 @@ def test_check_broadcast():
 
 def test_dtype_bytes_or_chars():
     assert misc.dtype_bytes_or_chars(np.dtype(np.float64)) == 8
-    assert misc.dtype_bytes_or_chars(np.dtype(object)) == (8 if NUMPY_LT_1_10 else None)
+    assert misc.dtype_bytes_or_chars(np.dtype(object)) == (
+        np.dtype(object).itemsize if NUMPY_LT_1_10 else None)
     assert misc.dtype_bytes_or_chars(np.dtype(np.int32)) == 4
     assert misc.dtype_bytes_or_chars(np.array(b'12345').dtype) == 5
     assert misc.dtype_bytes_or_chars(np.array(u'12345').dtype) == 5
