@@ -2,11 +2,12 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-from ...extern import six
-
 import io
 
+import pytest
+
 from ..xml import check, unescaper, writer
+from ...extern import six
 
 
 def test_writer():
@@ -48,14 +49,14 @@ def test_check_anyuri():
 
 def test_unescape_all():
     # str
-    url_in = 'http://casu.ast.cam.ac.uk/ag/iphas-dsa/SubmitCone?' \
+    url_in = 'http://casu.ast.cam.ac.uk/ag/iphas-dsa%2FSubmitCone?' \
              'DSACAT=IDR&amp;amp;DSATAB=Emitters&amp;amp;'
     url_out = 'http://casu.ast.cam.ac.uk/ag/iphas-dsa/SubmitCone?' \
               'DSACAT=IDR&DSATAB=Emitters&'
     assert unescaper.unescape_all(url_in) == url_out
 
     # bytes
-    url_in = b'http://casu.ast.cam.ac.uk/ag/iphas-dsa/SubmitCone?' \
+    url_in = b'http://casu.ast.cam.ac.uk/ag/iphas-dsa%2FSubmitCone?' \
              b'DSACAT=IDR&amp;amp;DSATAB=Emitters&amp;amp;'
     url_out = b'http://casu.ast.cam.ac.uk/ag/iphas-dsa/SubmitCone?' \
               b'DSACAT=IDR&DSATAB=Emitters&'
@@ -74,3 +75,37 @@ def test_escape_xml():
     s = writer.xml_escape(b'This & That')
     assert type(s) == bytes
     assert s == b'This &amp; That'
+
+
+@pytest.mark.skipif('writer.HAS_BLEACH')
+def test_escape_xml_without_bleach():
+    fh = io.StringIO()
+    w = writer.XMLWriter(fh)
+
+    with pytest.raises(ValueError) as err:
+        with w.xml_cleaning_method('bleach_clean'):
+            pass
+    assert 'bleach package is required when HTML escaping is disabled' in str(err)
+
+
+@pytest.mark.skipif('not writer.HAS_BLEACH')
+def test_escape_xml_with_bleach():
+    fh = io.StringIO()
+    w = writer.XMLWriter(fh)
+
+    # Turn off XML escaping, but still sanitize unsafe tags like <script>
+    with w.xml_cleaning_method('bleach_clean'):
+        w.start('td')
+        w.data('<script>x</script> <em>OK</em>')
+        w.end(indent=False)
+    assert fh.getvalue() == '<td>&lt;script&gt;x&lt;/script&gt; <em>OK</em></td>\n'
+
+    fh = io.StringIO()
+    w = writer.XMLWriter(fh)
+
+    # Default is True (all XML tags escaped)
+    with w.xml_cleaning_method():
+        w.start('td')
+        w.data('<script>x</script> <em>OK</em>')
+        w.end(indent=False)
+    assert fh.getvalue() == '<td>&lt;script&gt;x&lt;/script&gt; &lt;em&gt;OK&lt;/em&gt;</td>\n'
