@@ -42,7 +42,7 @@ def validate_schema(filename, schema_file):
         raise TypeError("schema_file must be a path to an XML Schema or DTD")
 
     p = subprocess.Popen(
-        "xmllint --noout --nonet %s %s" % (schema_part, filename),
+        "xmllint --noout --nonet {} {}".format(schema_part, filename),
         shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     stdout, stderr = p.communicate()
 
