@@ -6,6 +6,8 @@ from __future__ import (absolute_import, division, print_function,
 
 import io
 
+import pytest
+
 try:
     import matplotlib.pyplot as plt
 except ImportError:
@@ -13,10 +15,6 @@ except ImportError:
 else:
     HAS_PLT = True
 
-
-from ...tests.helper import pytest
-
-
 from ... import units as u
 from ..units import quantity_support
 
