@@ -2,9 +2,13 @@
 
 # The following few lines skip this module when running tests if matplotlib is
 # not available (and will have no impact otherwise)
-from ...tests.helper import pytest
-pytest.importorskip("matplotlib.pyplot")
-del pytest
+
+try:
+    import pytest
+    pytest.importorskip("matplotlib")
+    del pytest
+except ImportError:
+    pass
 
 from .core import *
 from .coordinate_helpers import CoordinateHelper
@@ -30,4 +34,5 @@ class Conf(_config.ConfigNamespace):
     grid_samples = _config.ConfigItem(1000,
         'How many points to sample along grid lines.')
 
+
 conf = Conf()
