@@ -19,6 +19,7 @@ from ...coordinates import (ICRS, BaseCoordinateFrame, Longitude, Latitude,
 from ...units import Quantity
 from ...utils.timer import timefunc, RunTimePredictor
 from ...utils.exceptions import AstropyUserWarning
+from ...utils.decorators import deprecated
 from ...utils import data
 
 __all__ = ['AsyncConeSearch', 'conesearch', 'AsyncSearchAll', 'search_all',
@@ -30,6 +31,8 @@ __all__ = ['AsyncConeSearch', 'conesearch', 'AsyncSearchAll', 'search_all',
 __doctest_skip__ = ['AsyncConeSearch', 'AsyncSearchAll']
 
 
+@deprecated(
+    '2.0', alternative='astroquery.vo_conesearch.conesearch.AsyncConeSearch')
 class AsyncConeSearch(AsyncBase):
     """Perform a Cone Search asynchronously and returns the result of the
     first successful query.
@@ -76,6 +79,8 @@ class AsyncConeSearch(AsyncBase):
         super(AsyncConeSearch, self).__init__(conesearch, *args, **kwargs)
 
 
+@deprecated(
+    '2.0', alternative='astroquery.vo_conesearch.conesearch.conesearch')
 def conesearch(center, radius, verb=1, **kwargs):
     """Perform Cone Search and returns the result of the
     first successful query.
@@ -188,6 +193,8 @@ def conesearch(center, radius, verb=1, **kwargs):
                                        kwargs=args, **kwargs)
 
 
+@deprecated(
+    '2.0', alternative='astroquery.vo_conesearch.conesearch.AsyncSearchAll')
 class AsyncSearchAll(AsyncBase):
     """Perform a Cone Search asynchronously, storing all results
     instead of just the result from first successful query.
@@ -233,6 +240,8 @@ class AsyncSearchAll(AsyncBase):
         AsyncBase.__init__(self, search_all, *args, **kwargs)
 
 
+@deprecated(
+    '2.0', alternative='astroquery.vo_conesearch.conesearch.search_all')
 def search_all(*args, **kwargs):
     """Perform Cone Search and returns the results of
     all successful queries.
@@ -285,6 +294,8 @@ def search_all(*args, **kwargs):
     return all_results
 
 
+@deprecated(
+    '2.0', alternative='astroquery.vo_conesearch.conesearch.list_catalogs')
 def list_catalogs(**kwargs):
     """Return the available Cone Search catalogs as a list of strings.
     These can be used for the ``catalog_db`` argument to
@@ -321,6 +332,8 @@ def list_catalogs(**kwargs):
     return vos_catalog.list_catalogs(conf.conesearch_dbname, **kwargs)
 
 
+@deprecated(
+    '2.0', alternative='astroquery.vo_conesearch.conesearch.predict_search')
 def predict_search(url, *args, **kwargs):
     """Predict the run time needed and the number of objects
     for a Cone Search for the given access URL, position, and
@@ -454,6 +467,8 @@ def predict_search(url, *args, **kwargs):
     return t_est, n_est
 
 
+@deprecated(
+    '2.0', alternative='astroquery.vo_conesearch.conesearch.conesearch_timer')
 @timefunc(1)
 def conesearch_timer(*args, **kwargs):
     """Time a single Cone Search using `astropy.utils.timer.timefunc`
