@@ -3,4 +3,8 @@
 
 def get_package_data():
     return {
-        'astropy.vo.client.tests': ['data/*.xml']}
+        'astropy.vo.client.tests': ['data/*.xml', 'data/*.json']}
+
+
+def requires_2to3():
+    return False
