@@ -3,7 +3,7 @@
 
 from __future__ import division, print_function
 
-import numpy
+import numpy as np
 from astropy import wcs
 from astropy.io import fits
 import sys
@@ -23,7 +23,7 @@ def load_wcs_from_file(filename):
 
     # Three pixel coordinates of interest.
     # Note we've silently assumed a NAXIS=2 image here
-    pixcrd = numpy.array([[0, 0], [24, 38], [45, 98]], numpy.float_)
+    pixcrd = np.array([[0, 0], [24, 38], [45, 98]], np.float_)
 
     # Convert pixel coordinates to world coordinates
     # The second argument is "origin" -- in this case we're declaring we
@@ -37,7 +37,7 @@ def load_wcs_from_file(filename):
 
     # These should be the same as the original pixel coordinates, modulo
     # some floating-point error.
-    assert numpy.max(numpy.abs(pixcrd - pixcrd2)) < 1e-6
+    assert np.max(np.abs(pixcrd - pixcrd2)) < 1e-6
 
 
 if __name__ == '__main__':
